@@ -4,50 +4,61 @@ New input endpoint types are created by implementing it.
 
 import base64
 import hashlib
-import json
+import os
 import zlib
 from abc import abstractmethod
 from functools import partial
 from hmac import HMAC
-from typing import Tuple, Optional
+from typing import TYPE_CHECKING, Optional, Tuple
 
-import arrow
 from attrs import define, field, validators
 
 from logprep.abc.connector import Connector
+from logprep.metrics.metrics import Metric
 from logprep.util.helper import add_field_to, get_dotted_field_value
-from logprep.util.time_measurement import TimeMeasurement
+from logprep.util.time import UTC, TimeParser
 from logprep.util.validators import dict_structure_validator
 
+if TYPE_CHECKING:  # pragma: no cover
+    from logprep.abc.output import Output
 
-class InputError(BaseException):
+
+class InputError(Exception):
     """Base class for Input related exceptions."""
 
+    def __init__(self, input_connector: "Input", message: str) -> None:
+        input_connector.metrics.number_of_errors += 1
+        super().__init__(f"{self.__class__.__name__} in {input_connector.describe()}: {message}")
+
 
 class CriticalInputError(InputError):
     """A significant error occurred - log and don't process the event."""
 
-    def __init__(self, message, raw_input):
+    def __init__(self, input_connector: "Input", message, raw_input):
         self.raw_input = raw_input
-        super().__init__(message)
+        super().__init__(input_connector, f"{message} -> {raw_input}")
+
+
+class CriticalInputParsingError(CriticalInputError):
+    """The input couldn't be parsed correctly."""
 
 
 class FatalInputError(InputError):
     """Must not be catched."""
 
 
-class WarningInputError(InputError):
+class InputWarning(Exception):
     """May be catched but must be displayed to the user/logged."""
 
+    def __init__(self, input_connector: "Input", message: str) -> None:
+        input_connector.metrics.number_of_warnings += 1
+        super().__init__(f"{self.__class__.__name__} in {input_connector.describe()}: {message}")
 
-class SourceDisconnectedError(WarningInputError):
+
+class SourceDisconnectedWarning(InputWarning):
     """Lost (or failed to establish) contact with the source."""
 
 
-class InfoInputError(InputError):
-    """Informational exceptions, e.g. to inform that a timeout occurred"""
-
-
 @define(kw_only=True)
 class HmacConfig:
     """Hmac Configurations
@@ -100,6 +111,7 @@ class Input(Connector):
                         "hmac": Optional[HmacConfig],
                         "log_arrival_time_target_field": Optional[str],
                         "log_arrival_timedelta": Optional[TimeDeltaConfig],
+                        "enrich_by_env_variables": Optional[dict],
                     },
                 ),
             ],
@@ -157,6 +169,9 @@ class Input(Connector):
               containing the original message that was used to calculate the hmac in compressed and
               base64 encoded. In case the output field exists already in the original message an
               error is raised.
+        - `enrich_by_env_variables` - If required it is possible to automatically enrich incoming
+          events by environment variables. To activate this preprocessor the fields value has to be
+          a mapping from the target field name (key) to the environment variable name (value).
         """
 
         _version_information: dict = field(
@@ -168,7 +183,8 @@ class Input(Connector):
         )
 
     pipeline_index: int
-    __slots__ = ["pipeline_index"]
+    output_connector: Optional["Output"]
+    __slots__ = ["pipeline_index", "output_connector"]
 
     @property
     def _add_hmac(self):
@@ -197,7 +213,22 @@ class Input(Connector):
         )
         return log_arrival_time_target_field_present & log_arrival_timedelta_present
 
-    def _get_raw_event(self, timeout: float) -> bytearray:
+    @property
+    def metric_labels(self) -> dict:
+        """Return the metric labels for this component."""
+        return {
+            "component": "input",
+            "description": self.describe(),
+            "type": self._config.type,
+            "name": self.name,
+        }
+
+    @property
+    def _add_env_enrichment(self):
+        """Check and return if the env enrichment should be added to the event."""
+        return bool(self._config.preprocessing.get("enrich_by_env_variables"))
+
+    def _get_raw_event(self, timeout: float) -> bytearray:  # pylint: disable=unused-argument
         """Implements the details how to get the raw event
 
         Parameters
@@ -226,7 +257,7 @@ class Input(Connector):
         (event, raw_event)
         """
 
-    @TimeMeasurement.measure_time()
+    @Metric.measure_time()
     def get_next(self, timeout: float) -> Tuple[Optional[dict], Optional[str]]:
         """Return the next document
 
@@ -249,8 +280,9 @@ class Input(Connector):
         non_critical_error_msg = None
         if event is None:
             return None, None
-        if event is not None and not isinstance(event, dict):
-            raise CriticalInputError("not a dict", event)
+        self.metrics.number_of_processed_events += 1
+        if not isinstance(event, dict):
+            raise CriticalInputError(self, "not a dict", event)
         if self._add_hmac:
             event, non_critical_error_msg = self._add_hmac_to(event, raw_event)
         if self._add_version_info:
@@ -259,14 +291,23 @@ class Input(Connector):
             self._add_arrival_time_information_to_event(event)
         if self._add_log_arrival_timedelta_information:
             self._add_arrival_timedelta_information_to_event(event)
-        self.metrics.number_of_processed_events += 1
+        if self._add_env_enrichment:
+            self._add_env_enrichment_to_event(event)
         return event, non_critical_error_msg
 
     def batch_finished_callback(self):
         """Can be called by output connectors after processing a batch of one or more records."""
 
+    def _add_env_enrichment_to_event(self, event: dict):
+        """Add the env enrichment information to the event"""
+        enrichments = self._config.preprocessing.get("enrich_by_env_variables")
+        if not enrichments:
+            return
+        for target_field, variable_name in enrichments.items():
+            add_field_to(event, target_field, os.environ.get(variable_name, ""))
+
     def _add_arrival_time_information_to_event(self, event: dict):
-        now = arrow.now()
+        now = TimeParser.now()
         target_field = self._config.preprocessing.get("log_arrival_time_target_field")
         add_field_to(event, target_field, now.isoformat())
 
@@ -281,7 +322,8 @@ class Input(Connector):
         log_arrival_time = get_dotted_field_value(event, log_arrival_time_target_field)
         if time_reference:
             delta_time_sec = (
-                arrow.get(log_arrival_time) - arrow.get(time_reference)
+                TimeParser.from_string(log_arrival_time).astimezone(UTC)
+                - TimeParser.from_string(time_reference).astimezone(UTC)
             ).total_seconds()
             add_field_to(event, target_field, delta_time_sec)
 
@@ -319,7 +361,7 @@ class Input(Connector):
         non_critical_error_msg = None
 
         if raw_event is None:
-            raw_event = json.dumps(event_dict).encode("utf-8")
+            raw_event = self._encoder.encode(event_dict)
 
         if hmac_target_field_name == "<RAW_MSG>":
             received_orig_message = raw_event
