@@ -17,13 +17,16 @@ Example
         type: dummy_output
 """
 from logging import Logger
-from typing import List
+from typing import TYPE_CHECKING, List
 
-from attr import field, define
+from attr import define, field
 from attrs import validators
 
 from logprep.abc.output import Output
 
+if TYPE_CHECKING:
+    from logprep.abc.connector import Connector  # pragma: no cover
+
 
 class DummyOutput(Output):
     """
@@ -83,7 +86,7 @@ class DummyOutput(Output):
         if self._exceptions:
             exception = self._exceptions.pop(0)
             if exception is not None:
-                raise Exception(exception)
+                raise Exception(exception)  # pylint: disable=broad-exception-raised
         self.events.append(document)
         self.metrics.number_of_processed_events += 1
         if self.input_connector:
@@ -95,6 +98,7 @@ class DummyOutput(Output):
 
     def store_failed(self, error_message: str, document_received: dict, document_processed: dict):
         """Store an event when an error occurred during the processing."""
+        self.metrics.number_of_failed_events += 1
         self.failed_events.append((error_message, document_received, document_processed))
 
     def shut_down(self):
