@@ -13,9 +13,9 @@ Example
     output:
       my_jsonl_output:
         type: jsonl_output
-        output_file = path/to/output.file
-        output_file_custom = ""
-        output_file_error = ""
+        output_file: path/to/output.file
+        output_file_custom: ""
+        output_file_error: ""
 """
 
 import json
@@ -89,8 +89,10 @@ class JsonlOutput(Output):
 
         if self._config.output_file_custom:
             JsonlOutput._write_json(self._config.output_file_custom, document)
+        self.metrics.number_of_processed_events += 1
 
     def store_failed(self, error_message: str, document_received: dict, document_processed: dict):
+        self.metrics.number_of_failed_events += 1
         self.failed_events.append((error_message, document_received, document_processed))
 
         if self._config.output_file_error:
