@@ -1,9 +1,9 @@
 """This module contains all filter expressions used for matching rules."""
 
-from typing import List, Any
 import re
-from itertools import chain, zip_longest
 from abc import ABC, abstractmethod
+from itertools import chain, zip_longest
+from typing import List, Any
 
 
 class FilterExpressionError(BaseException):
@@ -17,6 +17,21 @@ class KeyDoesNotExistError(FilterExpressionError):
 class FilterExpression(ABC):
     """Base class for all filter expression used for matching rules."""
 
+    def __init__(self, *children: "FilterExpression"):
+        """Initializes children for filter expression.
+
+        Filter expression can contain multiple child filter expression,
+        i.e. a 'Not' expression could contain a child that gets negated,
+        or an 'And' expression could contain multiple children that must all match.
+
+        Parameters
+        ----------
+        children : FilterExpression
+            Child expression of this expression.
+
+        """
+        self.children = children
+
     def matches(self, document: dict) -> bool:
         """Receives a document and returns True if it is matched by the expression.
 
@@ -62,10 +77,9 @@ class FilterExpression(ABC):
 
         """
 
-    # Return the value for the given key from
-    # the document.
     @staticmethod
     def _get_value(key: List[str], document: dict) -> Any:
+        """Return the value for the given key from the document."""
         if not key:
             raise KeyDoesNotExistError
 
@@ -83,21 +97,18 @@ class FilterExpression(ABC):
             return False
         return True
 
-    @staticmethod
-    def _as_dotted_string(key_list: List[str]) -> str:
-        return ".".join([str(i) for i in key_list])
-
 
 class Always(FilterExpression):
     """Filter expression that can be set to match always or never."""
 
     def __init__(self, value: Any):
+        super().__init__()
         self._value = value
 
     def __repr__(self):
         if self._value:
-            return "TRUE"
-        return "FALSE"
+            return "*"
+        return ""
 
     def does_match(self, document: dict):
         return self._value
@@ -107,21 +118,18 @@ class Not(FilterExpression):
     """Filter expression that negates a match."""
 
     def __init__(self, expression: FilterExpression):
-        self.expression = expression
+        super().__init__(expression)
 
     def __repr__(self) -> str:
-        return f"NOT({str(self.expression)})"
+        return f"NOT ({repr(self.children[0])})"
 
     def does_match(self, document: dict) -> bool:
-        return not self.expression.matches(document)
+        return not self.children[0].matches(document)
 
 
 class CompoundFilterExpression(FilterExpression):
     """Base class of filter expressions that combine other filter expressions."""
 
-    def __init__(self, *args: FilterExpression):
-        self.expressions = args
-
     def does_match(self, document: dict):
         raise NotImplementedError
 
@@ -130,31 +138,58 @@ class And(CompoundFilterExpression):
     """Compound filter expression that is a logical conjunction."""
 
     def __repr__(self) -> str:
-        return f'AND({", ".join([str(i) for i in self.expressions])})'
+        return f'({" AND ".join([str(exp) for exp in self.children])})'
 
     def does_match(self, document: dict) -> bool:
-        return all((expression.matches(document) for expression in self.expressions))
+        return all((expression.matches(document) for expression in self.children))
 
 
 class Or(CompoundFilterExpression):
     """Compound filter expression that is a logical disjunction."""
 
     def __repr__(self) -> str:
-        return f'OR({", ".join([str(i) for i in self.expressions])})'
+        return f'({" OR ".join([str(exp) for exp in self.children])})'
 
     def does_match(self, document: dict) -> bool:
-        return any((expression.matches(document) for expression in self.expressions))
+        return any((expression.matches(document) for expression in self.children))
 
 
-class KeyValueBasedFilterExpression(FilterExpression):
+class KeyBasedFilterExpression(FilterExpression):
+    """Base class of filter expressions that match a certain value on a given key."""
+
+    def __init__(self, key: List[str]):
+        super().__init__()
+        self.key = key
+        self._key_as_dotted_string = ".".join([str(i) for i in self.key])
+
+    def __repr__(self) -> str:
+        return f"{self.key_as_dotted_string}"
+
+    def does_match(self, document):
+        raise NotImplementedError
+
+    @property
+    def key_as_dotted_string(self) -> str:
+        """Converts key of expression to dotted string.
+
+        Returns
+        -------
+        str
+            Returns dotted string.
+
+        """
+        return self._key_as_dotted_string
+
+
+class KeyValueBasedFilterExpression(KeyBasedFilterExpression):
     """Base class of filter expressions that match a certain value on a given key."""
 
     def __init__(self, key: List[str], expected_value: Any):
-        self._key = key
+        super().__init__(key)
         self._expected_value = expected_value
 
     def __repr__(self) -> str:
-        return f"{self._as_dotted_string(self._key)}:{str(self._expected_value)}"
+        return f"{self.key_as_dotted_string}:{str(self._expected_value)}"
 
     def does_match(self, document):
         raise NotImplementedError
@@ -164,14 +199,14 @@ class StringFilterExpression(KeyValueBasedFilterExpression):
     """Key value filter expression that matches for a string."""
 
     def does_match(self, document: dict) -> bool:
-        value = self._get_value(self._key, document)
+        value = self._get_value(self.key, document)
 
         if isinstance(value, list):
             return self._expected_value in value
         return str(value) == self._expected_value
 
     def __repr__(self) -> str:
-        return f'{self._as_dotted_string(self._key)}:"{str(self._expected_value)}"'
+        return f'{self.key_as_dotted_string}:"{str(self._expected_value)}"'
 
 
 class WildcardStringFilterExpression(KeyValueBasedFilterExpression):
@@ -179,8 +214,8 @@ class WildcardStringFilterExpression(KeyValueBasedFilterExpression):
 
     flags = 0
 
-    wc = re.compile(r".*?((?:\\)*\*).*?")
-    wq = re.compile(r".*?((?:\\)*\?).*?")
+    wc = re.compile(r"((?:\\)*\*)")
+    wq = re.compile(r"((?:\\)*\?)")
 
     def __init__(self, key: List[str], expected_value: Any):
         super().__init__(key, expected_value)
@@ -200,7 +235,7 @@ class WildcardStringFilterExpression(KeyValueBasedFilterExpression):
         return f"^{regex}$"
 
     def does_match(self, document: dict) -> bool:
-        value = self._get_value(self._key, document)
+        value = self._get_value(self.key, document)
 
         if isinstance(value, list):
             return any(filter(self._matcher.match, (str(val) for val in value)))
@@ -223,7 +258,7 @@ class WildcardStringFilterExpression(KeyValueBasedFilterExpression):
         return "".join([x for x in chain.from_iterable(zip_longest(split, matches)) if x])
 
     def __repr__(self) -> str:
-        return f'{self._as_dotted_string(self._key)}:"{self._expected_value}"'
+        return f'{self.key_as_dotted_string}:"{self._expected_value}"'
 
 
 class SigmaFilterExpression(WildcardStringFilterExpression):
@@ -236,7 +271,7 @@ class IntegerFilterExpression(KeyValueBasedFilterExpression):
     """Key value filter expression that matches for an integer."""
 
     def does_match(self, document: dict) -> bool:
-        value = self._get_value(self._key, document)
+        value = self._get_value(self.key, document)
 
         return value == self._expected_value
 
@@ -245,21 +280,21 @@ class FloatFilterExpression(KeyValueBasedFilterExpression):
     """Key value filter expression that matches for a float."""
 
     def does_match(self, document: dict) -> bool:
-        value = self._get_value(self._key, document)
+        value = self._get_value(self.key, document)
 
         return value == self._expected_value
 
 
-class RangeBasedFilterExpression(FilterExpression):
+class RangeBasedFilterExpression(KeyBasedFilterExpression):
     """Base class of filter expressions that match for a range of values."""
 
     def __init__(self, key: List[str], lower_bound: float, upper_bound: float):
-        self._key = key
+        super().__init__(key)
         self._lower_bound = lower_bound
         self._upper_bound = upper_bound
 
     def __repr__(self) -> str:
-        return f"{self._as_dotted_string(self._key)}:[{self._lower_bound} TO {self._upper_bound}]"
+        return f"{self.key_as_dotted_string}:[{self._lower_bound} TO {self._upper_bound}]"
 
     def does_match(self, document: dict):
         raise NotImplementedError
@@ -269,7 +304,7 @@ class IntegerRangeFilterExpression(RangeBasedFilterExpression):
     """Range based filter expression that matches for integers."""
 
     def does_match(self, document: dict) -> bool:
-        value = self._get_value(self._key, document)
+        value = self._get_value(self.key, document)
 
         return self._lower_bound <= value <= self._upper_bound
 
@@ -278,59 +313,56 @@ class FloatRangeFilterExpression(RangeBasedFilterExpression):
     """Range based filter expression that matches for floats."""
 
     def does_match(self, document: dict) -> bool:
-        value = self._get_value(self._key, document)
+        value = self._get_value(self.key, document)
 
         return self._lower_bound <= value <= self._upper_bound
 
 
-class RegExFilterExpression(FilterExpression):
+class RegExFilterExpression(KeyValueBasedFilterExpression):
     """Filter expression that matches a value using regex."""
 
+    match_escaping_pattern = re.compile(r".*?(?P<escaping>\\*)\$$")
+    match_parts_pattern = re.compile(r"^(?P<flag>\(\?\w\))?(?P<start>\^)?(?P<pattern>.*)")
+
     def __init__(self, key: List[str], regex: str):
-        self._key = key
         self._regex = self._normalize_regex(regex)
         self._matcher = re.compile(self._regex)
-
-    def __repr__(self) -> str:
-        return f"{self._as_dotted_string(self._key)}:r/{self._regex}/"
+        super().__init__(key, f"/{self._regex.strip('^$')}/")
 
     @staticmethod
     def _normalize_regex(regex: str) -> str:
-        match = re.match(r".*?(?P<escaping>\\*)\$$", regex)
+        match = RegExFilterExpression.match_escaping_pattern.match(regex)
         if match and len(match.group("escaping")) % 2 == 0:
             end_token = ""
         else:
             end_token = "$"
-        match = re.match(r"^(?P<flag>\(\?\w\))?(?P<start>\^)?(?P<pattern>.*)", regex)
+        match = RegExFilterExpression.match_parts_pattern.match(regex)
         flag, _, pattern = match.groups()
         flag = "" if flag is None else flag
         pattern = "" if pattern is None else pattern
         return rf"{flag}^{pattern}{end_token}"
 
     def does_match(self, document: dict) -> bool:
-        value = self._get_value(self._key, document)
+        value = self._get_value(self.key, document)
 
         if isinstance(value, list):
             return any(filter(self._matcher.match, value))
         return self._matcher.match(str(value)) is not None
 
 
-class Exists(FilterExpression):
+class Exists(KeyBasedFilterExpression):
     """Filter expression that returns true if a given field exists."""
 
-    def __init__(self, value: list):
-        self.split_field = value
-
     def __repr__(self) -> str:
-        return f'"{self._as_dotted_string(self.split_field)}"'
+        return f"{self.key_as_dotted_string}: *"
 
     def does_match(self, document: dict) -> bool:
-        if not self.split_field:
+        if not self.key:
             return False
 
         try:
             current = document
-            for sub_field in self.split_field:
+            for sub_field in self.key:
                 if (
                     sub_field not in current.keys()
                 ):  # .keys() is important as it is used to "check" for dict
@@ -345,15 +377,12 @@ class Exists(FilterExpression):
         return True
 
 
-class Null(FilterExpression):
+class Null(KeyBasedFilterExpression):
     """Filter expression that returns true if a given field is set to null."""
 
-    def __init__(self, key: List[str]):
-        self._key = key
-
     def __repr__(self) -> str:
-        return f"{self._as_dotted_string(self._key)}:{None}"
+        return f"{self.key_as_dotted_string}:{None}"
 
     def does_match(self, document: dict) -> bool:
-        value = self._get_value(self._key, document)
+        value = self._get_value(self.key, document)
         return value is None
