@@ -1,14 +1,13 @@
 """
 Concatenator
-------------
+============
 
 The `concatenator` processor allows to concat a list of source fields into one new target field. The
 concat separator and the target field can be specified. Furthermore, it is possible to directly
 delete all given source fields, or to overwrite the specified target field.
 
-
-Example
-^^^^^^^
+Processor Configuration
+^^^^^^^^^^^^^^^^^^^^^^^
 ..  code-block:: yaml
     :linenos:
 
@@ -18,11 +17,18 @@ Example
             - tests/testdata/rules/specific/
         generic_rules:
             - tests/testdata/rules/generic/
+
+.. autoclass:: logprep.processor.concatenator.processor.Concatenator.Config
+   :members:
+   :undoc-members:
+   :inherited-members:
+   :noindex:
+
+.. automodule:: logprep.processor.concatenator.rule
 """
-from logprep.abc.processor import Processor
-from logprep.processor.base.exceptions import DuplicationError
 from logprep.processor.concatenator.rule import ConcatenatorRule
-from logprep.util.helper import add_field_to, get_dotted_field_value
+from logprep.processor.field_manager.processor import FieldManager
+from logprep.util.helper import get_dotted_field_value
 
 
 class ConcatenatorError(BaseException):
@@ -32,7 +38,7 @@ class ConcatenatorError(BaseException):
         super().__init__(f"Concatenator ({name}): {message}")
 
 
-class Concatenator(Processor):
+class Concatenator(FieldManager):
     """Concatenates a list of source fields into a new target field."""
 
     rule_class = ConcatenatorRule
@@ -50,17 +56,13 @@ class Concatenator(Processor):
         rule :
             Currently applied concatenator rule.
         """
-
         source_field_values = []
         for source_field in rule.source_fields:
             field_value = get_dotted_field_value(event, source_field)
             source_field_values.append(field_value)
+        self._handle_missing_fields(event, rule, rule.source_fields, source_field_values)
 
         source_field_values = [field for field in source_field_values if field is not None]
         target_value = f"{rule.separator}".join(source_field_values)
 
-        adding_was_successful = add_field_to(
-            event, rule.target_field, target_value, overwrite_output_field=rule.overwrite_target
-        )
-        if not adding_was_successful:
-            raise DuplicationError(self.name, [rule.target_field])
+        self._write_target_field(event, rule, target_value)
