@@ -1,7 +1,7 @@
 """
-Deleter
-=======
-The deleter processor deletes the entire log message if the filter produces a match.
+Rule Configuration
+^^^^^^^^^^^^^^^^^^
+
 The example below deletes the log message if the message field equals "foo".
 
 ..  code-block:: yaml
@@ -12,13 +12,17 @@ The example below deletes the log message if the message field equals "foo".
     deleter:
         delete: true
     description: '...'
+
+.. autoclass:: logprep.processor.deleter.rule.DeleterRule.Config
+   :members:
+   :undoc-members:
+   :inherited-members:
+   :noindex:
 """
-import warnings
 
 from attrs import define, field, validators
 
 from logprep.processor.base.rule import Rule
-from logprep.util.helper import pop_dotted_field_value, add_and_overwrite
 
 
 class DeleterRule(Rule):
@@ -30,17 +34,7 @@ class DeleterRule(Rule):
 
         delete: bool = field(validator=validators.instance_of(bool))
         """Delete or not"""
-
-    @classmethod
-    def normalize_rule_dict(cls, rule: dict) -> None:
-        if rule.get("deleter") is None:
-            deleter_config = pop_dotted_field_value(rule, "delete")
-            if deleter_config is not None:
-                add_and_overwrite(rule, "deleter.delete", deleter_config)
-                warnings.warn(
-                    "delete is deprecated. Use deleter.delete instead",
-                    DeprecationWarning,
-                )
+        target_field = field(init=False, repr=False, eq=False)
 
     @property
     def delete_event(self) -> bool:
