@@ -5,11 +5,10 @@ Dissector
 The `dissector` is a processor that tokenizes incoming strings using defined patterns.
 The behavior is based of the logstash dissect filter plugin and has the same advantage that
 for the event processing no regular expressions are used.
-Additionally it can be used to convert datatypes of given fields.
+Additionally, it can be used to convert datatypes of given fields.
 
-
-Example
-^^^^^^^
+Processor Configuration
+^^^^^^^^^^^^^^^^^^^^^^^
 ..  code-block:: yaml
     :linenos:
 
@@ -19,15 +18,23 @@ Example
             - tests/testdata/rules/specific/
         generic_rules:
             - tests/testdata/rules/generic/
+
+.. autoclass:: logprep.processor.dissector.processor.Dissector.Config
+   :members:
+   :undoc-members:
+   :inherited-members:
+   :noindex:
+
+.. automodule:: logprep.processor.dissector.rule
 """
 from typing import Callable, List, Tuple
 
-from logprep.abc.processor import Processor
 from logprep.processor.dissector.rule import DissectorRule
-from logprep.util.helper import get_dotted_field_value, add_field_to
+from logprep.processor.field_manager.processor import FieldManager
+from logprep.util.helper import add_field_to, get_dotted_field_value
 
 
-class Dissector(Processor):
+class Dissector(FieldManager):
     """A processor that tokenizes field values to new fields and converts datatypes"""
 
     rule_class = DissectorRule
@@ -47,17 +54,27 @@ class Dissector(Processor):
         current_field = None
         target_field_mapping = {}
         for rule_action in rule.actions:
-            source_field, delimeter, target_field, rule_action, separator, position = rule_action
+            (
+                source_field,
+                delimiter,
+                target_field,
+                rule_action,
+                separator,
+                strip_char,
+                position,
+            ) = rule_action
             if current_field != source_field:
                 current_field = source_field
                 loop_content = get_dotted_field_value(event, current_field)
                 if loop_content is None:
+                    if rule.ignore_missing_fields:
+                        continue
                     error = BaseException(
                         f"dissector: mapping field '{source_field}' does not exist"
                     )
                     self._handle_warning_error(event, rule, error)
-            if delimeter is not None:
-                content, _, loop_content = loop_content.partition(delimeter)
+            if delimiter is not None and loop_content is not None:
+                content, _, loop_content = loop_content.partition(delimiter)
             else:
                 content = loop_content
             if target_field.startswith("?"):
@@ -66,6 +83,8 @@ class Dissector(Processor):
                 content = ""
             if target_field.startswith("&"):
                 target_field = target_field_mapping.get(target_field.lstrip("&"))
+            if strip_char:
+                content = content.strip(strip_char)
             yield rule_action, event, target_field, content, separator, position
 
     def _apply_convert_datatype(self, event, rule):
