@@ -1,9 +1,6 @@
 """
-Dissector
-=========
-
-The dissector processor tokenizes values from fields into new fields or appends the value to
-existing fields. Additionally it can be used to convert datatypes of field values.
+Rule Configuration
+^^^^^^^^^^^^^^^^^^
 
 A speaking example:
 
@@ -44,21 +41,39 @@ Given a dissect pattern of :code:`%{field1} %{field2}` the source field value wi
 everything before the first whitespace which would be written into the field `field1` and everything
 after the first whitespace which would be written into the field `field2`.
 
-The string surrounded by :code:`%{` and :code:`}` is the desired target field. This can be declared
+The string between :code:`%{` and :code:`}` is the desired target field. This can be declared
 in dotted field notation (e.g. :code:`%{target.subfield1.subfield2}`). Every subfield between the
 first and the last subfield will be created if necessary.
 
-By default the target field will always be overwritten with the captured value. If you want to
+By default, the target field will always be overwritten with the captured value. If you want to
 append to a preexisting target field value, as string or list, you have to use
 the :code:`+` operator. If you want to use a prefix before the appended string use this notation
 :code:`+( )`. In this example a whitespace would be added before the extracted string is added.
 If you want to use the symbols :code:`(` or :code:`)` as your separator, you have to escape with
-:code:`\` (e.g. :code:`+(\()`)
+:code:`\\\` (e.g. :code:`+(\\\()`).
 
-It is possible to capture the target field name from the source field value with the notation
+If you want to remove unwanted padding characters around a dissected pattern you have to use the
+:code:`-(<char>)` notation, while :code:`<char>` can be any character similar to the :code:`+( )`
+notation. If for example you have a field like
+:code:`"[2022-11-04 10:00:00 AM     ] - 127.0.0.1"` and you want to extract the timestamp and the
+ip, you can use the dissect-pattern :code:`[%{time-( )}] - %{ip}` to remove the unwanted spaces
+after the 'AM'. This works independent of the number of spaces.
+
+It is also possible to capture the target field name from the source field value with the notation
 :code:`%{?<your name for the reference>}` (e.g. :code:`%{?key1}`). In the same dissection pattern
 this can be referred to with the notation :code:`%{&<the reference>}` (e.g. :code:`%{&key1}`).
-References can be combined with the append operator.
+References can be combined with the append operator. For examples see below.
+
+Additionally an optional convert datatype can be provided after the key using :code:`|` as separator
+to convert the value from string to :code:`int`, :code:`float` or :code:`bool`.
+The conversion to :code:`bool` is interpreted by meaning.
+(e.g. :code:`yes` is translated to :code:`True`). When removing padding characters at the same time
+then the conversion has to come after the padding character (e.g. :code:`%{field2-(#)|bool}`).
+
+If you want to reorder parts of a dissection you can give the order by adding :code:`/<position>` to
+the dissect pattern. A valid example would be: :code:`%{time/1} %{+time/3} %{+time/2}`. When
+removing padding characters at the same time then the position has to come after the padding
+character (e.g. :code:`%{time-(*)/2}`).
 
 .. autoclass:: logprep.processor.dissector.rule.DissectorRule.Config
    :members:
@@ -76,33 +91,50 @@ Examples for dissection and datatype conversion:
 import re
 from typing import Callable, List, Tuple
 
-from attrs import define, validators, field, Factory
+from attrs import define, field, validators
 
 from logprep.filter.expression.filter_expression import FilterExpression
 from logprep.processor.field_manager.rule import FieldManagerRule
-from logprep.util.helper import append, add_and_overwrite
+from logprep.util.helper import add_and_overwrite, append
 
 START = r"%\{"
 END = r"\}"
-VALID_TARGET_FIELD = r"[^\}\%\{\}\+]*"
+VALID_TARGET_FIELD = r"[^\}\%\{\}\+\/\|]*"
 APPEND_WITH_SEPERATOR = r"(\+\([^%]+\))"
 APPEND_WITHOUT_SEPERATOR = r"(\+(?!\([^%]))"
 INDIRECT_FIELD_NOTATION = r"([&\?]))"
 VALID_ACTION = rf"({APPEND_WITH_SEPERATOR}|{APPEND_WITHOUT_SEPERATOR}|{INDIRECT_FIELD_NOTATION}"
 VALID_POSITION = r"(\/\d*)"
-DISSECT = rf"{START}{VALID_ACTION}?{VALID_TARGET_FIELD}{VALID_POSITION}?{END}"
-DELIMETER = r"([^%]+)"
+VALID_DATATYPE = r"(\|(int|float|str|bool))"
+POSITION_OR_DATATYPE = rf"({VALID_POSITION}|{VALID_DATATYPE})"
+DISSECT = rf"{START}{VALID_ACTION}?{VALID_TARGET_FIELD}{POSITION_OR_DATATYPE}?{END}"
+DELIMITER = r"([^%]+)"
 ACTION = r"(?P<action>[+])?"
-SEPERATOR = r"(\((?P<separator>.+)\))?"
-TARGET_FIELD = r"(?P<target_field>[^\/]*)"
+STRIP_CHAR = r"(-\((?P<strip>.)\))?"
+SEPERATOR = r"(\((?P<separator>\\\)|[^)]+)\))?"
+TARGET_FIELD = r"(?P<target_field>[^\/\|-]*)"
 POSITION = r"(\/(?P<position>\d*))?"
-SECTION_MATCH = rf"{START}{ACTION}{SEPERATOR}{TARGET_FIELD}{POSITION}{END}(?P<delimeter>.*)"
+DATATYPE = r"(\|(?P<datatype>int|float|bool))?"
+SECTION_MATCH = rf"{START}{ACTION}{SEPERATOR}{TARGET_FIELD}{STRIP_CHAR}{POSITION}{DATATYPE}{END}(?P<delimiter>.*)"
+
+MAPPING_VALIDATION_REGEX = re.compile(rf"^({DELIMITER})?({DISSECT}({DELIMITER})?)+({DISSECT})?$")
 
 
 def _do_nothing(*_):
     return
 
 
+def str_to_bool(input_str: str) -> bool:
+    """converts an input string to bool by meaning"""
+    try:
+        if input_str.lower() in ("yes", "true", "on", "y"):
+            return True
+        return bool(int(input_str))
+    except (ValueError, AttributeError):
+        pass
+    return False
+
+
 class DissectorRule(FieldManagerRule):
     """dissector rule"""
 
@@ -110,20 +142,18 @@ class DissectorRule(FieldManagerRule):
     class Config(FieldManagerRule.Config):
         """Config for Dissector"""
 
-        source_fields: list = field(factory=list)
-        target_field: str = field(default="")
+        source_fields: list = field(factory=list, init=False, repr=False, eq=False)
+        target_field: str = field(default="", init=False, repr=False, eq=False)
 
         mapping: dict = field(
             validator=[
                 validators.instance_of(dict),
                 validators.deep_mapping(
                     key_validator=validators.instance_of(str),
-                    value_validator=validators.matches_re(
-                        rf"^({DELIMETER})?({DISSECT}{DELIMETER})+({DISSECT})?$"
-                    ),
+                    value_validator=validators.matches_re(MAPPING_VALIDATION_REGEX),
                 ),
             ],
-            default=Factory(dict),
+            factory=dict,
         )
         """A mapping from source fields to a dissect pattern [optional].
         Dotted field notation is possible in key and in the dissect pattern.
@@ -133,29 +163,31 @@ class DissectorRule(FieldManagerRule):
                 validators.instance_of(dict),
                 validators.deep_mapping(
                     key_validator=validators.instance_of(str),
-                    value_validator=validators.in_(["float", "int", "string"]),
+                    value_validator=validators.in_(["float", "int", "bool", "string"]),
                 ),
             ],
-            default=Factory(dict),
+            factory=dict,
         )
         """A mapping from source field and desired datatype [optional].
-        The datatypes could be [`float`, `int`, `string`]
+        The datatypes could be :code:`float`, :code:`int`, :code:`bool`, :code:`string`
         """
 
         def __attrs_post_init__(self):
             self.source_fields = list(self.mapping.keys())  # pylint: disable=no-member
+            super().__attrs_post_init__()
 
     _actions_mapping: dict = {
         None: add_and_overwrite,
         "+": append,
     }
 
-    _converter_mapping: dict = {"int": int, "float": float, "string": str}
+    _converter_mapping: dict = {"int": int, "float": float, "string": str, "bool": str_to_bool}
 
     _config: "DissectorRule.Config"
 
-    actions: List[Tuple[str, str, str, Callable, int]]
-    """list tuple format (<source_field>, <separator>, <target_field>, <function>), <position> """
+    actions: List[Tuple[str, str, str, Callable, str, str, int]]
+    """list tuple format (source_field, delimiter, target_field, action, separator, strip_char,
+    position)"""
 
     convert_actions: List[Tuple[str, Callable]]
     """list tuple format <target_field>, <converter callable>"""
@@ -165,8 +197,10 @@ class DissectorRule(FieldManagerRule):
         """Returns the failure tags"""
         return self._config.tag_on_failure
 
-    def __init__(self, filter_rule: FilterExpression, config: "DissectorRule.Config"):
-        super().__init__(filter_rule, config)
+    def __init__(
+        self, filter_rule: FilterExpression, config: "DissectorRule.Config", processor_name: str
+    ):
+        super().__init__(filter_rule, config, processor_name)
         self._set_mapping_actions()
         self._set_convert_actions()
 
@@ -184,13 +218,17 @@ class DissectorRule(FieldManagerRule):
                 separator = separator.replace("\\)", ")")
                 action_key = section_match.group("action")
                 target_field = section_match.group("target_field")
+                strip_char = section_match.group("strip")
+                datatype = section_match.group("datatype")
                 position = section_match.group("position")
-                delimeter = section_match.group("delimeter")
-                delimeter = None if delimeter == "" else delimeter
+                if datatype is not None:
+                    self._config.convert_datatype.update({target_field: datatype})
+                delimiter = section_match.group("delimiter")
+                delimiter = None if delimiter == "" else delimiter
                 position = int(position) if position is not None else 0
                 action = self._actions_mapping.get(action_key) if target_field else _do_nothing
                 self.actions.append(
-                    (source_field, delimeter, target_field, action, separator, position)
+                    (source_field, delimiter, target_field, action, separator, strip_char, position)
                 )
 
     def _set_convert_actions(self):
