@@ -1,10 +1,6 @@
 """
-FieldManager
-============
-
-The `field_manager` processor copies or moves field from multiple source fields to one target field.
-Additionaly it can be used to merge lists or simple values from source fields to
-one target field list.
+Rule Configuration
+^^^^^^^^^^^^^^^^^^
 
 A speaking example:
 
@@ -79,10 +75,10 @@ Examples for field_manager:
    :template: testcase-renderer.tmpl
 
 """
-from functools import partial
 from attrs import define, field, validators
-from logprep.util.validators import min_len_validator
+
 from logprep.processor.base.rule import Rule
+from logprep.util.helper import get_dotted_field_value
 
 FIELD_PATTERN = r"\$\{([+&?]?[^${}]*)\}"
 
@@ -98,12 +94,27 @@ class FieldManagerRule(Rule):
             validator=[
                 validators.instance_of(list),
                 validators.deep_iterable(member_validator=validators.instance_of(str)),
-                partial(min_len_validator, min_length=1),
-            ]
+            ],
+            default=[],
         )
-        """The fields from where to get the values which should be processed"""
-        target_field: str = field(validator=validators.instance_of(str))
-        """The field where to write the processed values to"""
+        """The fields from where to get the values which should be processed, requires
+        :code:`target_field`."""
+        target_field: str = field(validator=validators.instance_of(str), default="")
+        """The field where to write the processed values to. Can be used to move/copy single values,
+        merge multiple values to one list or extend a list. Requires :code:`source_field`."""
+        mapping: dict = field(
+            validator=[
+                validators.instance_of(dict),
+                validators.deep_mapping(
+                    key_validator=validators.instance_of(str),
+                    value_validator=validators.instance_of(str),
+                ),
+            ],
+            default={},
+        )
+        """A key-value mapping from source fields to target fields. Can be used to copy/move
+        multiple fields at once. If you want to move fields set :code:`delete_source_fields` to
+        true. Works independent of :code:`source_fields` and :code:`target_field`."""
         delete_source_fields: bool = field(validator=validators.instance_of(bool), default=False)
         """Whether to delete all the source fields or not. Defaults to :code:`False`"""
         overwrite_target: bool = field(validator=validators.instance_of(bool), default=False)
@@ -114,6 +125,15 @@ class FieldManagerRule(Rule):
         If the target field does not exist, a new field will be added with the
         source field value as list. Defaults to :code:`False`.
         """
+        ignore_missing_fields: bool = field(validator=validators.instance_of(bool), default=False)
+        """If set to :code:`True` missing fields will be ignored, no warning is logged and the event
+        is not tagged with the failure tag. Defaults to :code:`False`"""
+
+        def __attrs_post_init__(self):
+            # ensures no split operations during processing
+            for dotted_field in self.source_fields:  # pylint: disable=not-an-iterable
+                get_dotted_field_value({}, dotted_field)
+            get_dotted_field_value({}, self.target_field)
 
     # pylint: disable=missing-function-docstring
     @property
@@ -132,6 +152,10 @@ class FieldManagerRule(Rule):
     def target_field(self):
         return self._config.target_field
 
+    @property
+    def mapping(self):
+        return self._config.mapping
+
     @property
     def overwrite_target(self):
         return self._config.overwrite_target
@@ -140,4 +164,8 @@ class FieldManagerRule(Rule):
     def extend_target_list(self):
         return self._config.extend_target_list
 
+    @property
+    def ignore_missing_fields(self):
+        return self._config.ignore_missing_fields
+
     # pylint: enable=missing-function-docstring
