@@ -1,12 +1,12 @@
 """
 KeyChecker
-------------
+==========
 
 The `key_checker` processor checks if all field names in a provided list are
 given in the processed event.
 
-Example
-^^^^^^^
+Processor Configuration
+^^^^^^^^^^^^^^^^^^^^^^^
 ..  code-block:: yaml
     :linenos:
 
@@ -17,14 +17,21 @@ Example
         generic_rules:
             - tests/testdata/rules/generic/
 
+.. autoclass:: logprep.processor.key_checker.processor.KeyChecker.Config
+   :members:
+   :undoc-members:
+   :inherited-members:
+   :noindex:
+
+.. automodule:: logprep.processor.key_checker.rule
 """
 
 from typing import Iterable
+
 from logprep.abc.processor import Processor
 from logprep.processor.base.rule import Rule
 from logprep.processor.key_checker.rule import KeyCheckerRule
-from logprep.util.helper import add_field_to, get_dotted_field_value
-from logprep.processor.base.exceptions import DuplicationError
+from logprep.util.helper import get_dotted_field_value
 
 
 class KeyChecker(Processor):
@@ -33,7 +40,6 @@ class KeyChecker(Processor):
     rule_class: Rule = KeyCheckerRule
 
     def _apply_rules(self, event, rule):
-
         not_existing_fields = list(
             {
                 dotted_field
@@ -52,13 +58,4 @@ class KeyChecker(Processor):
         else:
             output_value = not_existing_fields
 
-        add_successful = add_field_to(
-            event,
-            rule.target_field,
-            sorted(output_value),
-            extends_lists=False,
-            overwrite_output_field=rule.overwrite_target,
-        )
-
-        if not add_successful:
-            raise DuplicationError(self.name, [rule.target_field])
+        self._write_target_field(event, rule, sorted(output_value))
