@@ -1,6 +1,6 @@
 """
-Labeler
-=======
+Rule Configuration
+^^^^^^^^^^^^^^^^^^
 
 The labeler requires the additional field :code:`label`.
 The keys under :code:`label` define the categories under which a label should be added.
@@ -20,13 +20,16 @@ to the labels of the category :code:`action`:
             - execute
     description: '...'
 
+.. autoclass:: logprep.processor.labeler.rule.LabelerRule.Config
+   :members:
+   :undoc-members:
+   :inherited-members:
+   :noindex:
 """
-import warnings
 from attrs import define, field, validators
 
 from logprep.processor.base.rule import Rule
 from logprep.processor.labeler.labeling_schema import LabelingSchema
-from logprep.util.helper import pop_dotted_field_value, add_and_overwrite
 
 
 class LabelerRule(Rule):
@@ -54,14 +57,6 @@ class LabelerRule(Rule):
 
     # pylint: enable=C0111
 
-    @classmethod
-    def normalize_rule_dict(cls, rule: dict) -> None:
-        """normalizes rule dict to stay backwards compatible"""
-        if rule.get("label") is not None:
-            label_value = pop_dotted_field_value(rule, "label")
-            add_and_overwrite(rule, "labeler.label", label_value)
-            warnings.warn("label is deprecated. Use labeler.label instead", DeprecationWarning)
-
     def conforms_to_schema(self, schema: LabelingSchema) -> bool:
         """Check if labels are valid."""
         return schema.validate_labels(self._config.label)
