@@ -1,6 +1,6 @@
 """
-PreDetector
-===========
+Rule Configuration
+^^^^^^^^^^^^^^^^^^
 
 The predetector requires the additional field :code:`pre_detector`.
 
@@ -26,7 +26,47 @@ The following example shows a complete rule:
       title: Rule one
     description: Some malicious event.
 
-Additionally the optional field :code:`ip_fields` can be specified.
+Applying this rule to the event
+
+..  code-block:: json
+    :linenos:
+    :caption: Example Input Event
+
+    {
+      "some_field": "very malicious!",
+    }
+
+would result in the following output and event enrichment
+
+..  code-block:: json
+    :linenos:
+    :caption: Enriched event
+
+    {
+      "some_field": "very malicious!",
+      "pre_detection_id": "80bfea3f-c24e-41d0-b82d-b2f02fc03ba9"
+    }
+
+..  code-block:: json
+    :linenos:
+    :caption: Generated extra output
+
+    {
+      "@timestamp": "2023-06-16T08:23:41.000Z",
+      "id": "RULE_ONE_ID",
+      "title": "Rule one",
+      "mitre": ["attack.something1", "attack.something2"],
+      "case_condition": "directly",
+      "rule_filter": "(some_field: 'very malicious!')",
+      "severity": "critical",
+      "pre_detection_id": "80bfea3f-c24e-41d0-b82d-b2f02fc03ba9",
+      "description": "Some malicious event."
+    }
+
+This generated extra output contains a corresponding :code:`rule_filter` in lucene notation, which
+can be used to further investigate this rule in an existing OpenSearch or ElasticSearch.
+
+Additionally, the optional field :code:`ip_fields` can be specified.
 It allows to specify a list of fields that can be compared to a list of IPs,
 which can be configured in the pipeline for the predetector.
 If this field was specified, then the rule will *only* trigger in case one of
@@ -47,10 +87,17 @@ the IPs from the list is also available in the specified fields.
     description: Some malicous event.
     ip_fields:
     - some_ip_field
-"""
 
-from typing import Union, Optional
-from attrs import define, field, validators, asdict
+.. autoclass:: logprep.processor.pre_detector.rule.PreDetectorRule.Config
+   :members:
+   :undoc-members:
+   :inherited-members:
+   :noindex:
+"""
+from functools import cached_property
+from typing import Optional, Union
+
+from attrs import asdict, define, field, validators
 
 from logprep.processor.base.rule import Rule
 
@@ -59,7 +106,7 @@ class PreDetectorRule(Rule):
     """Check if documents match a filter."""
 
     @define(kw_only=True)
-    class Config(Rule.Config):
+    class Config(Rule.Config):  # pylint: disable=too-many-instance-attributes
         """RuleConfig for Predetector"""
 
         id: str = field(validator=validators.instance_of((str, int)))
@@ -95,13 +142,13 @@ class PreDetectorRule(Rule):
         )
 
     # pylint: disable=C0111
-    @property
+    @cached_property
     def detection_data(self) -> dict:
-        detection_data = asdict(self._config)
+        detection_data = asdict(
+            self._config, filter=lambda attribute, _: attribute.name not in self.special_field_types
+        )
         if self._config.link is None:
             del detection_data["link"]
-        for special_field in Rule.special_field_types:
-            detection_data.pop(special_field)
         return detection_data
 
     @property
