@@ -9,12 +9,14 @@ from logprep.connector.console.output import ConsoleOutput
 from logprep.connector.dummy.input import DummyInput
 from logprep.connector.dummy.output import DummyOutput
 from logprep.connector.elasticsearch.output import ElasticsearchOutput
+from logprep.connector.file.input import FileInput
 from logprep.connector.http.input import HttpConnector
 from logprep.connector.json.input import JsonInput
 from logprep.connector.jsonl.input import JsonlInput
 from logprep.connector.jsonl.output import JsonlOutput
-from logprep.connector.file.input import FileInput
 from logprep.connector.opensearch.output import OpensearchOutput
+from logprep.connector.s3.output import S3Output
+from logprep.processor.amides.processor import Amides
 from logprep.processor.calculator.processor import Calculator
 from logprep.processor.clusterer.processor import Clusterer
 from logprep.processor.concatenator.processor import Concatenator
@@ -28,7 +30,9 @@ from logprep.processor.field_manager.processor import FieldManager
 from logprep.processor.generic_adder.processor import GenericAdder
 from logprep.processor.generic_resolver.processor import GenericResolver
 from logprep.processor.geoip_enricher.processor import GeoipEnricher
+from logprep.processor.grokker.processor import Grokker
 from logprep.processor.hyperscan_resolver.processor import HyperscanResolver
+from logprep.processor.ip_informer.processor import IpInformer
 from logprep.processor.key_checker.processor import KeyChecker
 from logprep.processor.labeler.processor import Labeler
 from logprep.processor.list_comparison.processor import ListComparison
@@ -37,8 +41,10 @@ from logprep.processor.pre_detector.processor import PreDetector
 from logprep.processor.pseudonymizer.processor import Pseudonymizer
 from logprep.processor.requester.processor import Requester
 from logprep.processor.selective_extractor.processor import SelectiveExtractor
+from logprep.processor.string_splitter.processor import StringSplitter
 from logprep.processor.template_replacer.processor import TemplateReplacer
 from logprep.processor.timestamp_differ.processor import TimestampDiffer
+from logprep.processor.timestamper.processor import Timestamper
 
 
 class Registry:
@@ -46,6 +52,7 @@ class Registry:
 
     mapping = {
         # Processors
+        "amides": Amides,
         "calculator": Calculator,
         "clusterer": Clusterer,
         "concatenator": Concatenator,
@@ -59,7 +66,9 @@ class Registry:
         "generic_adder": GenericAdder,
         "generic_resolver": GenericResolver,
         "geoip_enricher": GeoipEnricher,
+        "grokker": Grokker,
         "hyperscan_resolver": HyperscanResolver,
+        "ip_informer": IpInformer,
         "key_checker": KeyChecker,
         "labeler": Labeler,
         "list_comparison": ListComparison,
@@ -68,8 +77,10 @@ class Registry:
         "pseudonymizer": Pseudonymizer,
         "requester": Requester,
         "selective_extractor": SelectiveExtractor,
+        "string_splitter": StringSplitter,
         "template_replacer": TemplateReplacer,
         "timestamp_differ": TimestampDiffer,
+        "timestamper": Timestamper,
         # Connectors
         "json_input": JsonInput,
         "jsonl_input": JsonlInput,
@@ -83,6 +94,7 @@ class Registry:
         "jsonl_output": JsonlOutput,
         "opensearch_output": OpensearchOutput,
         "http_input": HttpConnector,
+        "s3_output": S3Output,
     }
 
     @classmethod
