@@ -93,12 +93,17 @@ def list_of_dirs_validator(_, attribute, directory_list):
         directory_validator(_, attribute, directory_path)
 
 
-def dict_with_keys_validator(_, __, value, expected_keys):
-    """validate if a dict has keys"""
+def keys_in_validator(_, __, value: typing.Iterable, expected_keys: typing.Iterable):
+    """validate if a Iterable has keys"""
     missing_keys = set(expected_keys).difference(set(value))
     if missing_keys:
         raise InvalidConfigurationError(f"following keys are missing: {missing_keys}")
 
+
+def dict_with_keys_validator(_, __, value, expected_keys):
+    """validate if a dict has keys"""
+    keys_in_validator(_, __, value, expected_keys)
+
     unexpected_keys = set(value).difference(set(expected_keys))
     if unexpected_keys:
         raise InvalidConfigurationError(f"following keys are unknown: {unexpected_keys}")
@@ -157,15 +162,6 @@ def _is_optional_type(given_type):
     return False
 
 
-def min_len_validator(_, attribute, value, min_length):
-    """Temporary Validator to check for min length"""
-    # TODO: This validator is available in attrs 22.1.0, currently semgrep depends on attrs 21.3,
-    #  meaning this custom validator can be removed once the semgrep incompatibility is resolved
-    #  (including the tests).
-    if len(value) < min_length:
-        raise ValueError(f"Length of '{attribute.name}' must be => {min_length}: {len(value)}")
-
-
 def one_of_validator(_, attribute, value, member_list):
     """validates if the value contains one element of the given list"""
     contains = False
