@@ -2,22 +2,18 @@
 # pylint: disable=line-too-long
 import pytest
 
-from tests.acceptance.util import (
-    get_test_output,
-    get_default_logprep_config,
-)
 from logprep.util.json_handling import dump_config_as_file
+from tests.acceptance.util import get_default_logprep_config, get_test_output
 
 
 @pytest.fixture(name="config")
 def config_fixture():
     pipeline = [
         {
-            "normalizername": {
-                "type": "normalizer",
-                "specific_rules": ["tests/testdata/acceptance/normalizer/rules_static/specific"],
-                "generic_rules": ["tests/testdata/acceptance/normalizer/rules_static/generic"],
-                "regex_mapping": "tests/testdata/acceptance/normalizer/rules_static/regex_mapping.yml",
+            "dissector": {
+                "type": "dissector",
+                "specific_rules": ["tests/testdata/acceptance/dissector/rules/specific"],
+                "generic_rules": ["tests/testdata/acceptance/dissector/rules/generic"],
             }
         },
         {
