@@ -1,47 +1,39 @@
 # pylint: disable=missing-docstring
 # pylint: disable=protected-access
+# pylint: disable=line-too-long
+# pylint: disable=unnecessary-dunder-call
 import base64
 import json
+import os
 import zlib
-from abc import ABC
 from copy import deepcopy
 from logging import getLogger
-from typing import Iterable
 from unittest import mock
 
-import arrow
-
 from logprep.abc.connector import Connector
 from logprep.abc.input import Input
 from logprep.abc.output import Output
 from logprep.factory import Factory
-from logprep.util.helper import camel_to_snake
-from logprep.util.time_measurement import TimeMeasurement
+from logprep.util.time import TimeParser
+from tests.unit.component.base import BaseComponentTestCase
 
 
-class BaseConnectorTestCase(ABC):
+class BaseConnectorTestCase(BaseComponentTestCase):
     CONFIG: dict = {}
     object: Connector = None
     logger = getLogger()
 
-    def setup_method(self) -> None:
-        config = {"Test Instance Name": self.CONFIG}
-        self.object = Factory.create(configuration=config, logger=self.logger)
+    expected_metrics = [
+        "logprep_processing_time_per_event",
+        "logprep_number_of_processed_events",
+        "logprep_number_of_failed_events",
+        "logprep_number_of_warnings",
+        "logprep_number_of_errors",
+    ]
 
     def test_is_a_connector_implementation(self):
         assert isinstance(self.object, Connector)
 
-    def test_uses_python_slots(self):
-        assert isinstance(self.object.__slots__, Iterable)
-
-    def test_describe(self):
-        describe_string = self.object.describe()
-        expected_base_description = f"{self.object.__class__.__name__} (Test Instance Name)"
-        assert describe_string.startswith(expected_base_description)
-
-    def test_snake_type(self):
-        assert str(self.object) == camel_to_snake(self.object.__class__.__name__)
-
 
 class BaseInputTestCase(BaseConnectorTestCase):
     def test_is_input_instance(self):
@@ -117,11 +109,11 @@ class BaseInputTestCase(BaseConnectorTestCase):
         assert processed_event.get("Hmac")
         calculated_hmac = processed_event.get("Hmac").get("hmac")
         assert (
-            calculated_hmac == "142454394037b655ec0663867172738319dbdbe669dedb7ccf8a69875f9fcd08"
+            calculated_hmac == "8b2d75efcba66476e5551d44065128bacff2f090db5b08d7a0201c33e3f651f5"
         ), f"Wrong hmac: '{calculated_hmac}'"
         calculated_compression = processed_event.get("Hmac").get("compressed_base64")
         assert (
-            calculated_compression == "eJyrVspNLS5OTE9VslJQKkktLlGA8WsBg/YJhQ=="
+            calculated_compression == "eJyrVspNLS5OTE9VslIqSS0uUYBxawF+Fwll"
         ), f"Wrong compression: {calculated_compression}"
 
     def test_get_next_with_hmac_of_raw_message(self):
@@ -359,13 +351,13 @@ class BaseInputTestCase(BaseConnectorTestCase):
         assert result is None
 
     def test_connector_metrics_counts_processed_events(self):
-        assert self.object.metrics.number_of_processed_events == 0
+        self.object.metrics.number_of_processed_events = 0
         self.object._get_event = mock.MagicMock(return_value=({"message": "test"}, None))
         self.object.get_next(0.01)
         assert self.object.metrics.number_of_processed_events == 1
 
     def test_connector_metrics_does_not_count_if_no_event_was_retrieved(self):
-        assert self.object.metrics.number_of_processed_events == 0
+        self.object.metrics.number_of_processed_events = 0
         self.object._get_event = mock.MagicMock(return_value=(None, None))
         self.object.get_next(0.01)
         assert self.object.metrics.number_of_processed_events == 0
@@ -386,7 +378,7 @@ class BaseInputTestCase(BaseConnectorTestCase):
         )
         assert target_field in result
         assert isinstance(result[target_field], str)
-        assert (arrow.now() - arrow.get(result[target_field])).total_seconds() > 0
+        assert (TimeParser.now() - TimeParser.from_string(result[target_field])).total_seconds() > 0
 
     def test_pipeline_preprocessing_does_not_add_log_arrival_time_if_target_field_exists_already(
         self,
@@ -480,18 +472,70 @@ class BaseInputTestCase(BaseConnectorTestCase):
         test_event = {"any": "content"}
         connector._get_event = mock.MagicMock(return_value=(test_event, None))
         result, _ = connector.get_next(0.01)
-        assert test_event == {"any": "content"}
+        assert result == {"any": "content"}
 
-    def test_get_next_returns_event_with_active_time_measurement(self):
-        TimeMeasurement.TIME_MEASUREMENT_ENABLED = True
-        TimeMeasurement.APPEND_TO_EVENT = True
+    def test_preprocessing_enriches_by_env_variable(self):
+        preprocessing_config = {
+            "preprocessing": {
+                "enrich_by_env_variables": {
+                    "enriched_field": "TEST_ENV_VARIABLE",
+                },
+            }
+        }
+        connector_config = deepcopy(self.CONFIG)
+        connector_config.update(preprocessing_config)
+        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        test_event = {"any": "content"}
+        os.environ["TEST_ENV_VARIABLE"] = "test_value"
+        connector._get_event = mock.MagicMock(return_value=(test_event, None))
+        result, _ = connector.get_next(0.01)
+        assert result == {"any": "content", "enriched_field": "test_value"}
+
+    def test_preprocessing_enriches_by_multiple_env_variables(self):
+        preprocessing_config = {
+            "preprocessing": {
+                "enrich_by_env_variables": {
+                    "enriched_field1": "TEST_ENV_VARIABLE_FOO",
+                    "enriched_field2": "TEST_ENV_VARIABLE_BAR",
+                },
+            }
+        }
+        connector_config = deepcopy(self.CONFIG)
+        connector_config.update(preprocessing_config)
+        connector = Factory.create({"test connector": connector_config}, logger=self.logger)
+        test_event = {"any": "content"}
+        os.environ["TEST_ENV_VARIABLE_FOO"] = "test_value_foo"
+        os.environ["TEST_ENV_VARIABLE_BAR"] = "test_value_bar"
+        connector._get_event = mock.MagicMock(return_value=(test_event, None))
+        result, _ = connector.get_next(0.01)
+        assert result == {
+            "any": "content",
+            "enriched_field1": "test_value_foo",
+            "enriched_field2": "test_value_bar",
+        }
+
+    def test_get_next_counts_number_of_processed_events(self):
+        self.object.metrics.number_of_processed_events = 0
         return_value = ({"message": "test message"}, b'{"message": "test message"}')
         self.object._get_event = mock.MagicMock(return_value=return_value)
-        event, _ = self.object.get_next(0.01)
-        assert isinstance(event, dict)
-        assert self.object.metrics.mean_processing_time_per_event > 0
-        TimeMeasurement.TIME_MEASUREMENT_ENABLED = False
-        TimeMeasurement.APPEND_TO_EVENT = False
+        self.object.get_next(0.01)
+        assert self.object.metrics.number_of_processed_events == 1
+
+    def test_get_next_doesnt_count_numer_of_processed_events_if_event_is_none(self):
+        self.object.metrics.number_of_processed_events = 0
+        self.object._get_event = mock.MagicMock(return_value=(None, None))
+        self.object.get_next(0.01)
+        assert self.object.metrics.number_of_processed_events == 0
+
+    def test_get_next_has_time_measurement(self):
+        mock_metric = mock.MagicMock()
+        self.object.metrics.processing_time_per_event = mock_metric
+        return_value = ({"message": "test message"}, b'{"message": "test message"}')
+        self.object._get_event = mock.MagicMock(return_value=return_value)
+        self.object.get_next(0.01)
+        assert isinstance(self.object.metrics.processing_time_per_event, mock.MagicMock)
+        # asserts entering context manager in metrics.metrics.Metric.measure_time
+        mock_metric.assert_has_calls([mock.call.tracker.labels().time().__enter__()])
 
 
 class BaseOutputTestCase(BaseConnectorTestCase):
@@ -499,10 +543,15 @@ class BaseOutputTestCase(BaseConnectorTestCase):
         assert isinstance(self.object, Output)
 
     def test_store_counts_processed_events(self):
-        assert self.object.metrics.number_of_processed_events == 0
+        self.object.metrics.number_of_processed_events = 0
         self.object.store({"message": "my event message"})
         assert self.object.metrics.number_of_processed_events == 1
 
+    def test_store_failed_counts_failed_events(self):
+        self.object.metrics.number_of_failed_events = 0
+        self.object.store_failed("error", {"message": "my event message"}, {})
+        assert self.object.metrics.number_of_failed_events == 1
+
     def test_store_calls_batch_finished_callback(self):
         self.object.input_connector = mock.MagicMock()
         self.object.store({"message": "my event message"})
