@@ -1,9 +1,12 @@
 # pylint: disable=missing-docstring
 # pylint: disable=attribute-defined-outside-init
 # pylint: disable=protected-access
+import copy
+
 from pytest import raises
 
-from logprep.abc.input import SourceDisconnectedError
+from logprep.abc.input import SourceDisconnectedWarning
+from logprep.factory import Factory
 from tests.unit.connector.base import BaseInputTestCase
 
 
@@ -17,7 +20,7 @@ class TestDummyInput(BaseInputTestCase):
     CONFIG = {"type": "dummy_input", "documents": []}
 
     def test_fails_with_disconnected_error_if_input_was_empty(self):
-        with raises(SourceDisconnectedError):
+        with raises(SourceDisconnectedWarning):
             self.object.get_next(self.timeout)
 
     def test_returns_documents_in_order_provided(self):
@@ -39,3 +42,13 @@ class TestDummyInput(BaseInputTestCase):
         self.object._config.documents = [BaseException]
         with raises(BaseException):
             self.object.get_next(self.timeout)
+
+    def test_repeat_documents_repeats_documents(self):
+        config = copy.deepcopy(self.CONFIG)
+        config["repeat_documents"] = True
+        connector = Factory.create(configuration={"Test Instance Name": config}, logger=self.logger)
+        connector._config.documents = [{"order": 0}, {"order": 1}, {"order": 2}]
+
+        for order in range(0, 9):
+            event, _ = connector.get_next(self.timeout)
+            assert event.get("order") == order % 3
