@@ -24,6 +24,7 @@ from logprep.filter.expression.filter_expression import (
     SigmaFilterExpression,
     Exists,
 )
+from logprep.filter.lucene_filter import LuceneFilter
 
 
 class TestFilterExpression:
@@ -46,8 +47,8 @@ class TestAlways:
         self.documents = [{}, {"key": "value"}, {"integer": 42}]
 
     def test_string_representation(self):
-        assert str(Always(True)) == "TRUE"
-        assert str(Always(False)) == "FALSE"
+        assert str(Always(True)) == "*"
+        assert str(Always(False)) == ""
 
     def test_different_objects_with_same_payload_are_equal(self):
         filter1 = Always(False)
@@ -66,7 +67,7 @@ class TestAlways:
 
 class TestNot:
     def test_string_representation(self):
-        assert str(Not(Always(True))) == "NOT(TRUE)"
+        assert str(Not(Always(True))) == "NOT (*)"
 
     def test_different_objects_with_same_payload_are_equal(self):
         not_filter1 = Not(Always(True))
@@ -85,7 +86,8 @@ class TestNot:
 
 class TestAnd:
     def test_string_representation(self):
-        assert str(And(Always(True))) == "AND(TRUE)"
+        assert str(And(Exists(["foo"]))) == "(foo: *)"
+        assert str(And(Exists(["foo"]), Exists(["bar"]))) == "(foo: * AND bar: *)"
 
     def test_different_objects_with_same_payload_are_equal(self):
         and_filter1 = And(Always(False))
@@ -123,7 +125,8 @@ class TestAnd:
 
 class TestOr:
     def test_string_representation(self):
-        assert str(Or(Always(True))) == "OR(TRUE)"
+        assert str(Or(Exists(["foo"]))) == "(foo: *)"
+        assert str(Or(Exists(["foo"]), Exists(["bar"]))) == "(foo: * OR bar: *)"
 
     def test_different_objects_with_same_payload_are_equal(self):
         or_filter1 = Or(Always(False))
@@ -281,7 +284,7 @@ class TestRegExFilterExpression(ValueBasedFilterExpressionTest):
         self.filter_identical = RegExFilterExpression(["key1", "key2"], self.regex)
 
     def test_string_representation(self):
-        assert str(self.filter) == "key1.key2:r/^start.*end$/"
+        assert str(self.filter) == "key1.key2:/start.*end/"
 
     def test_does_not_match_if_key_is_missing(self):
         assert not self.filter.matches({"not": {"the": {"key": "to match"}}})
@@ -339,7 +342,7 @@ class TestExistsFilterExpression(ValueBasedFilterExpressionTest):
         self.filter_identical = Exists(["key1", "key2"])
 
     def test_string_representation(self):
-        assert str(self.filter) == '"key1.key2"'
+        assert str(self.filter) == "key1.key2: *"
 
     def test_matches_any_value(self):
         filter = Exists(["key1", "key2"])
@@ -408,6 +411,33 @@ class TestWildcardFilterExpression(ValueBasedFilterExpressionTest):
                 }
             )
 
+    @pytest.mark.parametrize(
+        "filter_expression, expected_expression",
+        [
+            (r"*", r"^.*$"),
+            (r"?", r"^.?$"),
+            (r"(*)", r"^\(.*\)$"),
+            (r"(?)", r"^\(.?\)$"),
+            (r"**", r"^.*.*$"),
+            (r"??", r"^.?.?$"),
+            (r"start*end", r"^start.*end$"),
+            (r"start**end", r"^start.*.*end$"),
+            (r"start?end", r"^start.?end$"),
+            (r"\\", r"^\\\\$"),
+            (r"\\\\", r"^\\\\\\\\$"),
+            (r"\*", r"^\*$"),
+            (r"\\*", r"^\\.*$"),
+            (r"\\\*", r"^\\\\.*$"),
+            (r"\\\\*", r"^\\\\\\.*$"),
+            (r'"', r'^"$'),
+            (r"\"", r'^\\"$'),
+            (r'\\"', r'^\\\\"$'),
+        ],
+    )
+    def test_escaped_expected(self, filter_expression, expected_expression):
+        _filter = WildcardStringFilterExpression(["key1", "key2"], filter_expression)
+        assert _filter.escaped_expected == expected_expression
+
 
 class TestSigmaFilterExpression(ValueBasedFilterExpressionTest):
     def setup_method(self, _):
@@ -464,3 +494,87 @@ class TestSigmaFilterExpression(ValueBasedFilterExpressionTest):
                     }
                 }
             )
+
+    @pytest.mark.parametrize(
+        "filter_expression, expected_expression",
+        [
+            (r"*", r"^.*$"),
+            (r"?", r"^.?$"),
+            (r"(*)", r"^\(.*\)$"),
+            (r"(?)", r"^\(.?\)$"),
+            (r"**", r"^.*.*$"),
+            (r"??", r"^.?.?$"),
+            (r"start*end", r"^start.*end$"),
+            (r"start**end", r"^start.*.*end$"),
+            (r"start?end", r"^start.?end$"),
+            (r"\\", r"^\\\\$"),
+            (r"\\\\", r"^\\\\\\\\$"),
+            (r"\*", r"^\*$"),
+            (r"\\*", r"^\\.*$"),
+            (r"\\\*", r"^\\\\.*$"),
+            (r"\\\\*", r"^\\\\\\.*$"),
+            (r'"', r'^"$'),
+            (r"\"", r'^\\"$'),
+            (r'\\"', r'^\\\\"$'),
+            (r'te"st', r'^te"st$'),
+            (r'te\\"st', r'^te\\\\"st$'),
+            (r'te\\"st"', r'^te\\\\"st"$'),
+        ],
+    )
+    def test_escaped_expected(self, filter_expression, expected_expression):
+        _filter = SigmaFilterExpression(["key1", "key2"], filter_expression)
+        assert _filter.escaped_expected == expected_expression
+
+
+class TestLuceneRepresentation:
+    @pytest.mark.parametrize(
+        "logprep_filter_language, special_fields, expected_lucene_filter_query",
+        [
+            ("exist_field", None, "exist_field: *"),
+            ("key: value", None, 'key:"value"'),
+            ("dotted.key: value", None, 'dotted.key:"value"'),
+            ("*", None, "*"),
+            ("NOT key", None, "NOT (key: *)"),
+            ("NOT key: value", None, 'NOT (key:"value")'),
+            ("key: value1 AND keyy: value2", None, '(key:"value1" AND keyy:"value2")'),
+            (
+                "key: value1 AND keyy: value2 AND keyyy: value3",
+                None,
+                '(key:"value1" AND keyy:"value2" AND keyyy:"value3")',
+            ),
+            ("key: value1 OR key: value2", None, '(key:"value1" OR key:"value2")'),
+            (
+                "key: value1 AND keyy: value2 OR keyyy: value3",
+                None,
+                '((key:"value1" AND keyy:"value2") OR keyyy:"value3")',
+            ),
+            (
+                "key: value1 AND (keyy: value2 OR keyyy: value3)",
+                None,
+                '(key:"value1" AND (keyy:"value2" OR keyyy:"value3"))',
+            ),
+            (
+                "key: value1 AND (keyy: value2 OR NOT keyyy: value3)",
+                None,
+                '(key:"value1" AND (keyy:"value2" OR NOT (keyyy:"value3")))',
+            ),
+            ("key: val*", None, 'key:"val*"'),
+            ("key: 1", None, 'key:"1"'),
+            ("key: 1.0", None, 'key:"1.0"'),
+            (r"key: field\[\d\].*", {"regex_fields": ["key"]}, r"key:/field\[\d\].*/"),
+            (
+                r"nonRegexKey: something AND key: field\[\d\].*",
+                {"regex_fields": ["key"]},
+                r'(nonRegexKey:"something" AND key:/field\[\d\].*/)',
+            ),
+        ],
+    )
+    def test_convert_filter_to_best_closest_lucene_language(
+        self, logprep_filter_language, special_fields, expected_lucene_filter_query
+    ):
+        filter_expression = LuceneFilter.create(
+            logprep_filter_language, special_fields=special_fields
+        )
+        assert (
+            str(filter_expression) == expected_lucene_filter_query
+        ), f"Expected: '{expected_lucene_filter_query}', but got: '{filter_expression}'"
