@@ -1,8 +1,10 @@
 # pylint: disable=missing-docstring
 # pylint: disable=protected-access
+import logging
+import re
+
 import pytest
 
-from logprep.processor.base.exceptions import ProcessingWarning
 from tests.unit.processor.base import BaseProcessorTestCase
 
 
@@ -54,6 +56,7 @@ class TestConcatenator(BaseProcessorTestCase):
                         "separator": "-",
                         "overwrite_target": False,
                         "delete_source_fields": False,
+                        "ignore_missing_fields": True,
                     },
                 },
                 {"field": {"a": "first", "b": "second"}},
@@ -141,6 +144,26 @@ class TestConcatenator(BaseProcessorTestCase):
                 },
                 {"field": {"c": "another one"}, "target_field": "first-second"},
             ),
+            (
+                "ignore missing fields",
+                {
+                    "filter": "field.a",
+                    "concatenator": {
+                        "source_fields": ["field.a", "field.b", "other_field.c"],
+                        "target_field": "target_field",
+                        "separator": "-",
+                        "overwrite_target": False,
+                        "delete_source_fields": False,
+                        "ignore_missing_fields": True,
+                    },
+                },
+                {"field": {"a": "first"}, "other_field": {"c": "third"}},
+                {
+                    "field": {"a": "first"},
+                    "other_field": {"c": "third"},
+                    "target_field": "first-third",
+                },
+            ),
         ],
     )
     def test_for_expected_output(self, test_case, rule, document, expected_output):
@@ -149,7 +172,7 @@ class TestConcatenator(BaseProcessorTestCase):
         assert document == expected_output, test_case
 
     def test_process_raises_duplication_error_if_target_field_exists_and_should_not_be_overwritten(
-        self,
+        self, caplog
     ):
         rule = {
             "filter": "field.a",
@@ -163,13 +186,9 @@ class TestConcatenator(BaseProcessorTestCase):
         }
         self._load_specific_rule(rule)
         document = {"field": {"a": "first", "b": "second"}, "target_field": "has already content"}
-        with pytest.raises(
-            ProcessingWarning,
-            match=r"ProcessingWarning: \(Test Instance Name - The following fields could not be "
-            r"written, because one or more subfields existed and could not be extended: "
-            r"target_field\)",
-        ):
+        with caplog.at_level(logging.WARNING):
             self.object.process(document)
+        assert re.match(".*FieldExistsWarning.*", caplog.text)
         assert "target_field" in document
         assert document.get("target_field") == "has already content"
         assert document.get("tags") == ["_concatenator_failure"]
