@@ -105,15 +105,3 @@ class TestDeleterRule:
     def test_rule_is_hashable(self, specific_rule_definition):
         rule = DeleterRule._create_from_dict(specific_rule_definition)
         assert isinstance(rule, Hashable)
-
-    def test_deprecation_warning(self):
-        rule_dict = {
-            "filter": "field.a",
-            "delete": True,
-            "description": "",
-        }
-        with pytest.deprecated_call() as warnings:
-            DeleterRule._create_from_dict(rule_dict)
-            assert len(warnings.list) == 1
-            matches = [warning.message.args[0] for warning in warnings.list]
-            assert "delete is deprecated. Use deleter.delete instead" in matches[0]
