@@ -1,14 +1,19 @@
 # pylint: disable=missing-docstring
 # pylint: disable=protected-access
 # pylint: disable=anomalous-backslash-in-string
+# pylint: disable=line-too-long
 import pytest
 
 from logprep.processor.base.exceptions import InvalidRuleDefinitionError
-from logprep.processor.dissector.rule import DissectorRule, add_and_overwrite, append
+from logprep.processor.dissector.rule import (
+    DissectorRule,
+    add_and_overwrite,
+    append,
+    str_to_bool,
+)
 
 
 class TestDissectorRule:
-
     rule = {"filter": "message", "dissector": {"mapping": {}}}
 
     def test_create_from_dict_returns_dissector_rule(self):
@@ -74,8 +79,8 @@ class TestDissectorRule:
                     "filter": "message",
                     "dissector": {"mapping": {"field": "%{ts}"}},
                 },
-                ValueError,
-                "must match regex",
+                None,
+                None,
             ),
             (
                 {
@@ -125,7 +130,7 @@ class TestDissectorRule:
             (
                 {"filter": "message", "dissector": {"convert_datatype": {"field1": "char"}}},
                 ValueError,
-                r"'convert_datatype' must be in \['float', 'int', 'string'\]",
+                r"'convert_datatype' must be in \['float', 'int', 'bool', 'string'\]",
             ),
             (
                 {
@@ -191,6 +196,26 @@ class TestDissectorRule:
                 None,
                 None,
             ),
+            (
+                {
+                    "filter": "message",
+                    "dissector": {
+                        "mapping": {"message": "%{} %{} %{field1|int} %{} %{} %{} %{field2|bool}"}
+                    },
+                },
+                None,
+                None,
+            ),
+            (
+                {
+                    "filter": "message",
+                    "dissector": {
+                        "mapping": {"message": "%{} %{} %{field1/3|int} %{} %{} %{} %{field2|bool}"}
+                    },
+                },
+                ValueError,
+                "must match regex",
+            ),
         ],
     )
     def test_create_from_dict_validates_config(self, rule, error, message):
@@ -311,11 +336,11 @@ class TestDissectorRule:
                 "tag_on_failure": ["_failed"],
             },
         }
-        dissector_rule = DissectorRule._create_from_dict(rule)
-        assert dissector_rule.actions
-        assert dissector_rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", 0)
-        assert dissector_rule.actions[1] == ("field1", " ", "field3", add_and_overwrite, "", 0)
-        assert dissector_rule.actions[2] == ("field1", None, "field4", add_and_overwrite, "", 0)
+        rule = DissectorRule._create_from_dict(rule)
+        assert rule.actions
+        assert rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", None, 0)
+        assert rule.actions[1] == ("field1", " ", "field3", add_and_overwrite, "", None, 0)
+        assert rule.actions[2] == ("field1", None, "field4", add_and_overwrite, "", None, 0)
 
     def test_converts_mappings_with_append_operator_to_append_field_to_action(self):
         rule = {
@@ -325,11 +350,11 @@ class TestDissectorRule:
                 "tag_on_failure": ["_failed"],
             },
         }
-        dissector_rule = DissectorRule._create_from_dict(rule)
-        assert dissector_rule.actions
-        assert dissector_rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", 0)
-        assert dissector_rule.actions[1] == ("field1", " ", "field3", append, "", 0)
-        assert dissector_rule.actions[2] == ("field1", None, "field4", add_and_overwrite, "", 0)
+        rule = DissectorRule._create_from_dict(rule)
+        assert rule.actions
+        assert rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", None, 0)
+        assert rule.actions[1] == ("field1", " ", "field3", append, "", None, 0)
+        assert rule.actions[2] == ("field1", None, "field4", add_and_overwrite, "", None, 0)
 
     def test_converts_mappings_with_append_operator_and_order_modifier(self):
         rule = {
@@ -339,18 +364,18 @@ class TestDissectorRule:
                 "tag_on_failure": ["_failed"],
             },
         }
-        dissector_rule = DissectorRule._create_from_dict(rule)
-        assert dissector_rule.actions
-        assert dissector_rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", 0)
-        assert dissector_rule.actions[1] == ("field1", " ", "field3", append, "", 1)
-        assert dissector_rule.actions[2] == ("field1", None, "field4", append, "", 3)
+        rule = DissectorRule._create_from_dict(rule)
+        assert rule.actions
+        assert rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", None, 0)
+        assert rule.actions[1] == ("field1", " ", "field3", append, "", None, 1)
+        assert rule.actions[2] == ("field1", None, "field4", append, "", None, 3)
 
     def test_adds_convert_actions(self):
         rule = {"filter": "message", "dissector": {"convert_datatype": {"field1": "int"}}}
-        dissector_rule = DissectorRule._create_from_dict(rule)
-        assert dissector_rule.convert_actions
-        assert dissector_rule.convert_actions[0][0] == "field1"
-        assert dissector_rule.convert_actions[0][1] == int
+        rule = DissectorRule._create_from_dict(rule)
+        assert rule.convert_actions
+        assert rule.convert_actions[0][0] == "field1"
+        assert rule.convert_actions[0][1] == int
 
     def test_adds_multiple_convert_actions(self):
         rule = {
@@ -363,14 +388,14 @@ class TestDissectorRule:
                 }
             },
         }
-        dissector_rule = DissectorRule._create_from_dict(rule)
-        assert dissector_rule.convert_actions
-        assert dissector_rule.convert_actions[0][0] == "field1"
-        assert dissector_rule.convert_actions[0][1] == int
-        assert dissector_rule.convert_actions[1][0] == "other_field"
-        assert dissector_rule.convert_actions[1][1] == str
-        assert dissector_rule.convert_actions[2][0] == "yet another field"
-        assert dissector_rule.convert_actions[2][1] == float
+        rule = DissectorRule._create_from_dict(rule)
+        assert rule.convert_actions
+        assert rule.convert_actions[0][0] == "field1"
+        assert rule.convert_actions[0][1] == int
+        assert rule.convert_actions[1][0] == "other_field"
+        assert rule.convert_actions[1][1] == str
+        assert rule.convert_actions[2][0] == "yet another field"
+        assert rule.convert_actions[2][1] == float
 
     def test_parses_defined_separator(self):
         rule = {
@@ -380,11 +405,11 @@ class TestDissectorRule:
                 "tag_on_failure": ["_failed"],
             },
         }
-        dissector_rule = DissectorRule._create_from_dict(rule)
-        assert dissector_rule.actions
-        assert dissector_rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", 0)
-        assert dissector_rule.actions[1] == ("field1", " ", "field3", append, " ", 1)
-        assert dissector_rule.actions[2] == ("field1", None, "field4", append, ",", 3)
+        rule = DissectorRule._create_from_dict(rule)
+        assert rule.actions
+        assert rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", None, 0)
+        assert rule.actions[1] == ("field1", " ", "field3", append, " ", None, 1)
+        assert rule.actions[2] == ("field1", None, "field4", append, ",", None, 3)
 
     def test_parses_defined_multichar_separator(self):
         rule = {
@@ -394,11 +419,11 @@ class TestDissectorRule:
                 "tag_on_failure": ["_failed"],
             },
         }
-        dissector_rule = DissectorRule._create_from_dict(rule)
-        assert dissector_rule.actions
-        assert dissector_rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", 0)
-        assert dissector_rule.actions[1] == ("field1", " ", "field3", append, "separator", 1)
-        assert dissector_rule.actions[2] == ("field1", None, "field4", append, ",", 3)
+        rule = DissectorRule._create_from_dict(rule)
+        assert rule.actions
+        assert rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", None, 0)
+        assert rule.actions[1] == ("field1", " ", "field3", append, "separator", None, 1)
+        assert rule.actions[2] == ("field1", None, "field4", append, ",", None, 3)
 
     def test_parses_defined_special_chars_separator(self):
         rule = {
@@ -408,11 +433,11 @@ class TestDissectorRule:
                 "tag_on_failure": ["_failed"],
             },
         }
-        dissector_rule = DissectorRule._create_from_dict(rule)
-        assert dissector_rule.actions
-        assert dissector_rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", 0)
-        assert dissector_rule.actions[1] == ("field1", " ", "field3", append, "(", 1)
-        assert dissector_rule.actions[2] == ("field1", None, "field4", append, ")", 3)
+        rule = DissectorRule._create_from_dict(rule)
+        assert rule.actions
+        assert rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", None, 0)
+        assert rule.actions[1] == ("field1", " ", "field3", append, "(", None, 1)
+        assert rule.actions[2] == ("field1", None, "field4", append, ")", None, 3)
 
     def test_parses_defined_very_special_chars_separator(self):
         rule = {
@@ -422,8 +447,62 @@ class TestDissectorRule:
                 "tag_on_failure": ["_failed"],
             },
         }
-        dissector_rule = DissectorRule._create_from_dict(rule)
-        assert dissector_rule.actions
-        assert dissector_rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", 0)
-        assert dissector_rule.actions[1] == ("field1", " ", "field3", append, "#", 1)
-        assert dissector_rule.actions[2] == ("field1", None, "field4", append, "}", 3)
+        rule = DissectorRule._create_from_dict(rule)
+        assert rule.actions
+        assert rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", None, 0)
+        assert rule.actions[1] == ("field1", " ", "field3", append, "#", None, 1)
+        assert rule.actions[2] == ("field1", None, "field4", append, "}", None, 3)
+
+    def test_parses_strip_char(self):
+        rule = {
+            "filter": "message",
+            "dissector": {
+                "mapping": {"field1": "%{field2}:%{field3} %{field4-( )}"},
+                "tag_on_failure": ["_failed"],
+            },
+        }
+        rule = DissectorRule._create_from_dict(rule)
+        assert rule.actions
+        assert rule.actions[0] == ("field1", ":", "field2", add_and_overwrite, "", None, 0)
+        assert rule.actions[1] == ("field1", " ", "field3", add_and_overwrite, "", None, 0)
+        assert rule.actions[2] == ("field1", None, "field4", add_and_overwrite, "", " ", 0)
+
+    def test_parses_datatype_conversion_from_dissect_pattern(self):
+        rule = {
+            "filter": "message",
+            "dissector": {
+                "mapping": {"field1": "%{field2}:%{field3|int} %{field4}"},
+            },
+        }
+        rule = DissectorRule._create_from_dict(rule)
+        assert rule._config.convert_datatype.get("field3") == "int"
+        assert len(rule._config.convert_datatype.keys()) == 1
+
+    @pytest.mark.parametrize(
+        "input_str, expected",
+        [("yes", True), ("no", False), (None, False), ("42", True), ("on", True), ("off", False)],
+    )
+    def test_str_to_bool_returns(self, input_str, expected):
+        assert str_to_bool(input_str) == expected
+
+    def test_id_hash_generation(self):
+        rule = {
+            "filter": "message",
+            "dissector": {
+                "mapping": {"field1": "%{field2}:%{field3|int} %{field4}"},
+            },
+        }
+        rule1 = DissectorRule._create_from_dict(rule)
+        rule2 = DissectorRule._create_from_dict(rule)
+        assert rule1.id == rule2.id
+
+    def test_id_no_hash_if_set(self):
+        rule = {
+            "filter": "message",
+            "dissector": {
+                "id": "my_id",
+                "mapping": {"field1": "%{field2}:%{field3|int} %{field4}"},
+            },
+        }
+        rule = DissectorRule._create_from_dict(rule)
+        assert rule.id == "my_id"
