@@ -84,20 +84,3 @@ def test_rules_equality(specific_rule_definition, testcase, other_rule_definitio
     rule2 = DomainResolverRule._create_from_dict(other_rule_definition)
 
     assert (rule1 == rule2) == is_equal, testcase
-
-
-def test_deprecation_warning():
-    rule_dict = {
-        "filter": "message",
-        "domain_resolver": {
-            "source_url_or_domain": "foo",
-            "output_field": "other_bar",
-        },
-    }
-
-    with pytest.deprecated_call() as warnings:
-        DomainResolverRule._create_from_dict(rule_dict)
-        assert len(warnings.list) == 2
-        matches = [warning.message.args[0] for warning in warnings.list]
-        assert "Use domain_resolver.target_field instead" in matches[1]
-        assert "Use domain_resolver.source_fields instead" in matches[0]
