@@ -1,8 +1,10 @@
 # pylint: disable=missing-docstring
-import pytest
-from logprep.processor.base.exceptions import ProcessingWarning
-from tests.unit.processor.base import BaseProcessorTestCase
+import logging
+import re
 
+import pytest
+
+from tests.unit.processor.base import BaseProcessorTestCase
 
 test_cases = [  # testcase, rule, event, expected
     (
@@ -280,6 +282,144 @@ test_cases = [  # testcase, rule, event, expected
             },
         },
     ),
+    (
+        "copies multiple fields to multiple target fields",
+        {
+            "filter": "field",
+            "field_manager": {
+                "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
+            },
+        },
+        {"field": {"one": 1, "two": 2, "three": 3}},
+        {"field": {"one": 1, "two": 2, "three": 3}, "one": 1, "two": 2, "three": 3},
+    ),
+    (
+        "copies multiple fields to multiple target fields, while overwriting existing fields",
+        {
+            "filter": "field",
+            "field_manager": {
+                "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
+                "overwrite_target": True,
+            },
+        },
+        {"field": {"one": 1, "two": 2, "three": 3}, "three": "exists already"},
+        {"field": {"one": 1, "two": 2, "three": 3}, "one": 1, "two": 2, "three": 3},
+    ),
+    (
+        "copies multiple fields to multiple target fields, while one list will be extended",
+        {
+            "filter": "field",
+            "field_manager": {
+                "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
+                "extend_target_list": True,
+            },
+        },
+        {"field": {"one": 1, "two": 2, "three": 3}, "three": ["exists already"]},
+        {
+            "field": {"one": 1, "two": 2, "three": 3},
+            "one": 1,
+            "two": 2,
+            "three": ["exists already", 3],
+        },
+    ),
+    (
+        "copies multiple fields to multiple target fields, while one list will be extended with existing list",
+        {
+            "filter": "field",
+            "field_manager": {
+                "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
+                "extend_target_list": True,
+            },
+        },
+        {"field": {"one": 1, "two": 2, "three": [3, 3]}, "three": ["exists already"]},
+        {
+            "field": {"one": 1, "two": 2, "three": [3, 3]},
+            "one": 1,
+            "two": 2,
+            "three": ["exists already", 3, 3],
+        },
+    ),
+    (
+        "copies multiple fields to multiple target fields, while one target list will be overwritten with existing list",
+        {
+            "filter": "field",
+            "field_manager": {
+                "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
+                "overwrite_target": True,
+            },
+        },
+        {"field": {"one": 1, "two": 2, "three": [3, 3]}, "three": ["exists already"]},
+        {"field": {"one": 1, "two": 2, "three": [3, 3]}, "one": 1, "two": 2, "three": [3, 3]},
+    ),
+    (
+        "copies multiple fields to multiple target fields, while one source field is missing",
+        {
+            "filter": "field",
+            "field_manager": {
+                "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
+            },
+        },
+        {
+            "field": {"one": 1, "three": 3},
+        },
+        {
+            "field": {"one": 1, "three": 3},
+            "one": 1,
+            "three": 3,
+            "tags": ["_field_manager_missing_field_warning"],
+        },
+    ),
+    (
+        "moves multiple fields to multiple target fields",
+        {
+            "filter": "field",
+            "field_manager": {
+                "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
+                "delete_source_fields": True,
+            },
+        },
+        {"field": {"one": 1, "two": 2, "three": 3}},
+        {"one": 1, "two": 2, "three": 3},
+    ),
+    (
+        "Combine fields to list and copy fields at the same time",
+        {
+            "filter": "field",
+            "field_manager": {
+                "source_fields": ["source.one", "source.two"],
+                "target_field": "merged",
+                "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
+                "extend_target_list": True,
+            },
+        },
+        {"field": {"one": 1, "two": 2, "three": 3}, "source": {"one": ["a"], "two": ["b"]}},
+        {
+            "field": {"one": 1, "two": 2, "three": 3},
+            "source": {"one": ["a"], "two": ["b"]},
+            "one": 1,
+            "two": 2,
+            "three": 3,
+            "merged": ["a", "b"],
+        },
+    ),
+    (
+        "Ignore missing fields: No warning and no failure tag if source field is missing",
+        {
+            "filter": "field.a",
+            "field_manager": {
+                "mapping": {
+                    "field.a": "target_field",
+                    "does.not.exists": "target_field",
+                },
+                "ignore_missing_fields": True,
+            },
+        },
+        {"field": {"a": "first", "b": "second"}},
+        {
+            "field": {"a": "first", "b": "second"},
+            "target_field": "first",
+        },
+    ),
 ]
 
 failure_test_cases = [
@@ -293,7 +433,8 @@ failure_test_cases = [
             },
         },
         {"message": "This is a message"},
-        {"message": "This is a message", "tags": ["_field_manager_failure"]},
+        {"message": "This is a message", "tags": ["_field_manager_missing_field_warning"]},
+        ".*ProcessingWarning.*",
     ),
     (
         "single source field not found and preexisting tags",
@@ -305,7 +446,11 @@ failure_test_cases = [
             },
         },
         {"message": "This is a message", "tags": ["preexisting"]},
-        {"message": "This is a message", "tags": ["_field_manager_failure", "preexisting"]},
+        {
+            "message": "This is a message",
+            "tags": ["_field_manager_missing_field_warning", "preexisting"],
+        },
+        ".*ProcessingWarning.*",
     ),
     (
         "single source field not found and preexisting tags with deduplication",
@@ -316,14 +461,50 @@ failure_test_cases = [
                 "target_field": "new_field",
             },
         },
-        {"message": "This is a message", "tags": ["_field_manager_failure", "preexisting"]},
-        {"message": "This is a message", "tags": ["_field_manager_failure", "preexisting"]},
+        {
+            "message": "This is a message",
+            "tags": ["_field_manager_missing_field_warning", "preexisting"],
+        },
+        {
+            "message": "This is a message",
+            "tags": ["_field_manager_missing_field_warning", "preexisting"],
+        },
+        ".*ProcessingWarning.*",
     ),
-]  # testcase, rule, event, expected
+    (
+        "copies multiple fields to multiple target fields, while one target exists already",
+        {
+            "filter": "field",
+            "field_manager": {
+                "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
+            },
+        },
+        {"field": {"one": 1, "two": 2, "three": 3}, "three": "exists"},
+        {
+            "field": {"one": 1, "two": 2, "three": 3},
+            "one": 1,
+            "two": 2,
+            "three": "exists",
+            "tags": ["_field_manager_failure"],
+        },
+        ".*FieldExistsWarning.*",
+    ),
+    (
+        "tries to move multiple fields to multiple target fields but none exists",
+        {
+            "filter": "no-mapped-field",
+            "field_manager": {
+                "mapping": {"field.one": "one", "field.two": "two", "field.three": "three"},
+            },
+        },
+        {"no-mapped-field": "exists"},
+        {"no-mapped-field": "exists", "tags": ["_field_manager_missing_field_warning"]},
+        ".*ProcessingWarning.*",
+    ),
+]  # testcase, rule, event, expected, error
 
 
 class TestFieldManager(BaseProcessorTestCase):
-
     CONFIG: dict = {
         "type": "field_manager",
         "specific_rules": ["tests/testdata/unit/field_manager/specific_rules"],
@@ -336,15 +517,16 @@ class TestFieldManager(BaseProcessorTestCase):
         self.object.process(event)
         assert event == expected
 
-    @pytest.mark.parametrize("testcase, rule, event, expected", failure_test_cases)
-    def test_testcases_failure_handling(self, testcase, rule, event, expected):
+    @pytest.mark.parametrize("testcase, rule, event, expected, error", failure_test_cases)
+    def test_testcases_failure_handling(self, testcase, rule, event, expected, error, caplog):
         self._load_specific_rule(rule)
-        with pytest.raises(ProcessingWarning):
+        with caplog.at_level(logging.WARNING):
             self.object.process(event)
+        assert re.match(error, caplog.text)
         assert event == expected, testcase
 
     def test_process_raises_duplication_error_if_target_field_exists_and_should_not_be_overwritten(
-        self,
+        self, caplog
     ):
         rule = {
             "filter": "field.a",
@@ -357,20 +539,14 @@ class TestFieldManager(BaseProcessorTestCase):
         }
         self._load_specific_rule(rule)
         document = {"field": {"a": "first", "b": "second"}, "target_field": "has already content"}
-        with pytest.raises(
-            ProcessingWarning,
-            match=r"ProcessingWarning: \(Test Instance Name - The following fields could not be "
-            r"written, because one or more subfields existed and could not be extended: "
-            r"target_field\)",
-        ):
+        with caplog.at_level(logging.WARNING):
             self.object.process(document)
+        assert re.match(".*FieldExistsWarning.*", caplog.text)
         assert "target_field" in document
         assert document.get("target_field") == "has already content"
         assert document.get("tags") == ["_field_manager_failure"]
 
-    def test_process_raises_processing_warning_with_missing_fields(
-        self,
-    ):
+    def test_process_raises_processing_warning_with_missing_fields(self, caplog):
         rule = {
             "filter": "field.a",
             "field_manager": {
@@ -380,7 +556,60 @@ class TestFieldManager(BaseProcessorTestCase):
         }
         self._load_specific_rule(rule)
         document = {"field": {"a": "first", "b": "second"}}
-        with pytest.raises(
-            ProcessingWarning, match=r"missing source_fields: \['does.not.exists'\]"
-        ):
+        with caplog.at_level(logging.WARNING):
             self.object.process(document)
+        assert re.match(
+            r".*ProcessingWarning.*missing source_fields: \['does.not.exists'\]", caplog.text
+        )
+
+    def test_process_raises_processing_warning_with_missing_fields_but_event_is_processed(
+        self, caplog
+    ):
+        rule = {
+            "filter": "field.a",
+            "field_manager": {
+                "mapping": {
+                    "field.a": "target_field",
+                    "does.not.exists": "target_field",
+                }
+            },
+        }
+        self._load_specific_rule(rule)
+        document = {"field": {"a": "first", "b": "second"}}
+        expected = {
+            "field": {"a": "first", "b": "second"},
+            "target_field": "first",
+            "tags": ["_field_manager_missing_field_warning"],
+        }
+        with caplog.at_level(logging.WARNING):
+            self.object.process(document)
+        assert re.match(
+            r".*ProcessingWarning.*missing source_fields: \['does.not.exists'\]", caplog.text
+        )
+        assert document == expected
+
+    def test_process_dos_not_raises_processing_warning_with_missing_fields_and_event_is_processed(
+        self, caplog
+    ):
+        rule = {
+            "filter": "field.a",
+            "field_manager": {
+                "mapping": {
+                    "field.a": "target_field",
+                    "does.not.exists": "target_field",
+                },
+                "ignore_missing_fields": True,
+            },
+        }
+        self._load_specific_rule(rule)
+        document = {"field": {"a": "first", "b": "second"}}
+        expected = {
+            "field": {"a": "first", "b": "second"},
+            "target_field": "first",
+        }
+        with caplog.at_level(logging.WARNING):
+            self.object.process(document)
+        assert not re.match(
+            r".*ProcessingWarning.*missing source_fields: \['does.not.exists'\]", caplog.text
+        )
+        assert document == expected
