@@ -3,6 +3,7 @@
 # pylint: disable=unused-argument
 # pylint: disable=too-many-arguments
 import json
+import logging
 import os
 import re
 import tempfile
@@ -12,10 +13,9 @@ from unittest import mock
 
 import pytest
 
-from logprep.processor.base.exceptions import ProcessingWarning
-from logprep.processor.generic_adder.rule import InvalidGenericAdderDefinition
 from logprep.factory import Factory
 from logprep.factory_error import InvalidConfigurationError
+from logprep.processor.base.exceptions import InvalidRuleDefinitionError
 from tests.unit.processor.base import BaseProcessorTestCase
 
 RULES_DIR_MISSING = "tests/testdata/unit/generic_adder/rules_missing"
@@ -311,11 +311,7 @@ class TestGenericAdder(BaseProcessorTestCase):
                 "dotted": {"added": {"field": "yet_another_value"}},
                 "tags": ["_generic_adder_failure"],
             },
-            re.escape(
-                "ProcessingWarning: (Test Instance Name - The following fields could not be "
-                + "written, because one or more subfields existed and could not be extended: "
-                + "some_added_field)"
-            ),
+            r"subfields existed and could not be extended: some_added_field",
         ),
         (
             "Extend list field with 'extend_target_list' disabled",
@@ -339,11 +335,7 @@ class TestGenericAdder(BaseProcessorTestCase):
                 "dotted": {"added": {"field": "yet_another_value"}},
                 "tags": ["_generic_adder_failure"],
             },
-            re.escape(
-                "ProcessingWarning: (Test Instance Name - The following fields could not be "
-                + "written, because one or more subfields existed and could not be extended: "
-                + "some_added_field)"
-            ),
+            r"subfields existed and could not be extended: some_added_field",
         ),
         (
             "Extend list field with 'extend_target_list' enabled, but non-list target",
@@ -367,11 +359,7 @@ class TestGenericAdder(BaseProcessorTestCase):
                 "dotted": {"added": {"field": "yet_another_value"}},
                 "tags": ["_generic_adder_failure"],
             },
-            re.escape(
-                "ProcessingWarning: (Test Instance Name - The following fields could not be "
-                + "written, because one or more subfields existed and could not be extended: "
-                + "some_added_field)"
-            ),
+            r"subfields existed and could not be extended: some_added_field",
         ),
     ]
 
@@ -402,15 +390,16 @@ class TestGenericAdder(BaseProcessorTestCase):
 
     @pytest.mark.parametrize("testcase, rule, event, expected, error_message", failure_test_cases)
     def test_generic_adder_testcases_failure_handling(
-        self, testcase, rule, event, expected, error_message
+        self, testcase, rule, event, expected, error_message, caplog
     ):
         self._load_specific_rule(rule)
-        with pytest.raises(ProcessingWarning, match=error_message):
+        with caplog.at_level(logging.WARNING):
             self.object.process(event)
+        assert re.match(rf".*FieldExistsWarning.*{error_message}", caplog.text)
         assert event == expected, testcase
 
     def test_add_generic_fields_from_file_missing_and_existing_with_all_required(self):
-        with pytest.raises(InvalidGenericAdderDefinition, match=r"files do not exist"):
+        with pytest.raises(InvalidRuleDefinitionError, match=r"files do not exist"):
             config = deepcopy(self.CONFIG)
             config["specific_rules"] = [RULES_DIR_MISSING]
             configuration = {"test_instance_name": config}
@@ -418,7 +407,7 @@ class TestGenericAdder(BaseProcessorTestCase):
 
     def test_add_generic_fields_from_file_invalid(self):
         with pytest.raises(
-            InvalidGenericAdderDefinition,
+            InvalidRuleDefinitionError,
             match=r"must be a dictionary with string values",
         ):
             config = deepcopy(self.CONFIG)
@@ -593,7 +582,7 @@ class TestGenericAdderProcessorSQLWithoutAddedTarget(BaseTestGenericAdderSQLTest
         assert document_1 == expected
         assert document_2 == expected
 
-    def test_sql_database_raises_exception_on_duplicate(self):
+    def test_sql_database_raises_exception_on_duplicate(self, caplog):
         expected = {
             "add_from_sql_db_table": "Test",
             "source": "TEST_0.test.123",
@@ -603,8 +592,9 @@ class TestGenericAdderProcessorSQLWithoutAddedTarget(BaseTestGenericAdderSQLTest
         document = {"add_from_sql_db_table": "Test", "source": "TEST_0.test.123"}
 
         self.object.process(document)
-        with pytest.raises(ProcessingWarning):
+        with caplog.at_level(logging.WARNING):
             self.object.process(document)
+        assert re.match(".*FieldExistsWarning.*", caplog.text)
 
         assert document == expected
 
