@@ -2,17 +2,18 @@
 # pylint: disable=protected-access
 # pylint: disable=missing-docstring
 # pylint: disable=wrong-import-position
+import logging
+import re
 from collections import OrderedDict
 
 import pytest
 
-from logprep.processor.base.exceptions import ProcessingWarning
-from logprep.processor.generic_resolver.processor import GenericResolver, GenericResolverError
+from logprep.processor.base.exceptions import ProcessingCriticalError
+from logprep.processor.generic_resolver.processor import GenericResolver
 from tests.unit.processor.base import BaseProcessorTestCase
 
 
 class TestGenericResolver(BaseProcessorTestCase):
-
     CONFIG = {
         "type": "generic_resolver",
         "specific_rules": ["tests/testdata/unit/generic_resolver/rules/specific/"],
@@ -295,7 +296,7 @@ class TestGenericResolver(BaseProcessorTestCase):
         document = {"to_resolve": "ab"}
 
         with pytest.raises(
-            GenericResolverError,
+            ProcessingCriticalError,
             match=r"GenericResolver \(Test Instance Name\)\: Mapping group is missing in mapping "
             r"file pattern!",
         ):
@@ -314,7 +315,7 @@ class TestGenericResolver(BaseProcessorTestCase):
         document = {"to": {"resolve": "something HELLO1"}}
 
         with pytest.raises(
-            GenericResolverError,
+            ProcessingCriticalError,
             match=r"GenericResolver \(Test Instance Name\)\: Additions file \'foo\' not found!",
         ):
             self.object.process(document)
@@ -389,9 +390,7 @@ class TestGenericResolver(BaseProcessorTestCase):
 
         assert document == expected
 
-    def test_resolve_dotted_src_and_dest_field_and_conflict_match(
-        self,
-    ):
+    def test_resolve_dotted_src_and_dest_field_and_conflict_match(self, caplog):
         rule = {
             "filter": "to.resolve",
             "generic_resolver": {
@@ -410,8 +409,9 @@ class TestGenericResolver(BaseProcessorTestCase):
             "to": {"resolve": "something HELLO1"},
             "re": {"solved": "I already exist!"},
         }
-        with pytest.raises(ProcessingWarning):
+        with caplog.at_level(logging.WARNING):
             self.object.process(document)
+        assert re.match(".*FieldExistsWarning.*", caplog.text)
 
         assert document == expected
 
