@@ -2,31 +2,31 @@
 # pylint: disable=missing-docstring
 # pylint: disable=wrong-import-position
 # pylint: disable=wrong-import-order
+import logging
+import re
 from collections import OrderedDict
 from copy import deepcopy
 
 import pytest
 
-from logprep.processor.base.exceptions import ProcessingWarning
+from logprep.processor.base.exceptions import ProcessingCriticalError
 
 pytest.importorskip("hyperscan")
 
-from tests.unit.processor.base import BaseProcessorTestCase
-
 # pylint: disable=ungrouped-imports
-from logprep.processor.hyperscan_resolver.rule import (
-    InvalidHyperscanResolverDefinition,
-)
+from logprep.processor.hyperscan_resolver.rule import InvalidHyperscanResolverDefinition
+from tests.unit.processor.base import BaseProcessorTestCase
 
 # pylint: enable=ungrouped-imports
 
 pytest.importorskip("logprep.processor.hyperscan_resolver")
 
-from logprep.processor.hyperscan_resolver.processor import HyperscanResolver, HyperscanResolverError
+from logprep.processor.hyperscan_resolver.processor import (
+    HyperscanResolver,
+)
 
 
 class TestHyperscanResolverProcessor(BaseProcessorTestCase):
-
     CONFIG = {
         "type": "hyperscan_resolver",
         "specific_rules": ["tests/testdata/unit/hyperscan_resolver/rules/specific/"],
@@ -343,7 +343,7 @@ class TestHyperscanResolverProcessor(BaseProcessorTestCase):
 
         assert document == expected
 
-    def test_resolve_dotted_and_dest_field_with_conflict_match(self):
+    def test_resolve_dotted_and_dest_field_with_conflict_match(self, caplog):
         rule = {
             "filter": "to.resolve",
             "hyperscan_resolver": {
@@ -361,8 +361,9 @@ class TestHyperscanResolverProcessor(BaseProcessorTestCase):
             "tags": ["_hyperscan_resolver_failure"],
         }
 
-        with pytest.raises(ProcessingWarning):
+        with caplog.at_level(logging.WARNING):
             self.object.process(document)
+        assert re.match(".*FieldExistsWarning.*", caplog.text)
 
         assert document == expected
 
@@ -392,7 +393,6 @@ class TestHyperscanResolverProcessor(BaseProcessorTestCase):
 
 
 class TestHyperscanResolverProcessorWithPatterns(BaseProcessorTestCase):
-
     CONFIG = deepcopy(TestHyperscanResolverProcessor.CONFIG)
 
     def test_resolve_no_conflict_from_file(self):
@@ -627,7 +627,7 @@ class TestHyperscanResolverProcessorWithPatterns(BaseProcessorTestCase):
         document = {"to_resolve": "12ab34"}
 
         with pytest.raises(
-            HyperscanResolverError, match=r"No patter to compile for hyperscan database!"
+            ProcessingCriticalError, match=r"No patter to compile for hyperscan database!"
         ):
             self.object.process(document)
 
