@@ -5,25 +5,26 @@
 import calendar
 import copy
 import json
+import logging
 import os
+import re
 import tempfile
 from copy import deepcopy
 
-import arrow
 import pytest
+
+from logprep.factory import Factory
 from logprep.processor.base.exceptions import ProcessingWarning
-from logprep.processor.normalizer.processor import NormalizerError
 from logprep.processor.normalizer.rule import (
     InvalidGrokDefinition,
     InvalidNormalizationDefinition,
     NormalizerRule,
 )
-from logprep.factory import Factory
+from logprep.util.time import TimeParser
 from tests.unit.processor.base import BaseProcessorTestCase
 
 
 class TestNormalizer(BaseProcessorTestCase):
-
     CONFIG = {
         "type": "normalizer",
         "specific_rules": ["tests/testdata/unit/normalizer/rules/specific/"],
@@ -62,7 +63,7 @@ class TestNormalizer(BaseProcessorTestCase):
             == "Existing and normalized have the same value"
         )
 
-    def test_process_normalized_field_already_exists_with_different_content(self):
+    def test_process_normalized_field_already_exists_with_different_content(self, caplog):
         document = {
             "winlog": {
                 "api": "wineventlog",
@@ -71,13 +72,9 @@ class TestNormalizer(BaseProcessorTestCase):
             },
             "test_normalized": {"something": "I already exist but I am different!"},
         }
-        with pytest.raises(
-            ProcessingWarning,
-            match=r"ProcessingWarning: \(Test Instance Name - The following fields could not be "
-            r"written, because one or more subfields existed and could not be extended: "
-            r"test_normalized\.something\)",
-        ):
+        with caplog.at_level(logging.WARNING):
             self.object.process(document)
+        assert re.match(".*FieldExistsWarning.*", caplog.text)
 
         assert document["test_normalized"]["something"] == "I already exist but I am different!"
 
@@ -626,7 +623,7 @@ class TestNormalizer(BaseProcessorTestCase):
             "winlog>event_data>normalize me!": "123.123.123.123 1234"
         }
 
-    def test_normalization_from_grok_onto_existing(self):
+    def test_normalization_from_grok_onto_existing(self, caplog):
         event = {
             "winlog": {
                 "api": "wineventlog",
@@ -644,13 +641,9 @@ class TestNormalizer(BaseProcessorTestCase):
 
         self._load_specific_rule(rule)
 
-        with pytest.raises(
-            ProcessingWarning,
-            match=r"ProcessingWarning: \(Test Instance Name - The following fields could not be "
-            r"written, because one or more subfields existed and could not be extended: "
-            r"winlog\)",
-        ):
+        with caplog.at_level(logging.WARNING):
             self.object.process(event)
+        assert re.match(".*FieldExistsWarning.*", caplog.text)
 
     def test_incorrect_grok_identifier_definition(self):
         rule = {
@@ -973,7 +966,7 @@ class TestNormalizer(BaseProcessorTestCase):
 
         assert event == expected
 
-    def test_normalization_from_timestamp_with_non_matching_patterns(self):
+    def test_normalization_from_timestamp_with_non_matching_patterns(self, caplog):
         event = {
             "winlog": {
                 "api": "wineventlog",
@@ -983,6 +976,7 @@ class TestNormalizer(BaseProcessorTestCase):
         }
 
         expected = copy.deepcopy(event)
+        expected.update({"tags": ["_normalizer_failure"]})
 
         rule = {
             "filter": "winlog.event_id: 123456789",
@@ -999,9 +993,9 @@ class TestNormalizer(BaseProcessorTestCase):
         }
 
         self._load_specific_rule(rule)
-        with pytest.raises(NormalizerError):
+        with caplog.at_level(logging.WARNING):
             self.object.process(event)
-
+        assert re.match(".*NormalizerError.*", caplog.text)
         assert event == expected
 
     def test_normalization_from_timestamp_with_collision(self):
@@ -1010,7 +1004,7 @@ class TestNormalizer(BaseProcessorTestCase):
             "winlog": {
                 "api": "wineventlog",
                 "event_id": 123456789,
-                "event_data": {"some_timestamp_utc": "1999 12 12 - 12:12:22"},
+                "event_data": {"some_timestamp_berlin": "1999 12 12 - 12:12:22"},
             },
         }
 
@@ -1019,14 +1013,14 @@ class TestNormalizer(BaseProcessorTestCase):
             "winlog": {
                 "api": "wineventlog",
                 "event_id": 123456789,
-                "event_data": {"some_timestamp_utc": "1999 12 12 - 12:12:22"},
+                "event_data": {"some_timestamp_berlin": "1999 12 12 - 12:12:22"},
             },
         }
 
         rule = {
             "filter": "winlog.event_id: 123456789",
             "normalize": {
-                "winlog.event_data.some_timestamp_utc": {
+                "winlog.event_data.some_timestamp_berlin": {
                     "timestamp": {
                         "destination": "@timestamp",
                         "source_formats": ["%Y", "%Y %m %d - %H:%M:%S"],
@@ -1042,9 +1036,7 @@ class TestNormalizer(BaseProcessorTestCase):
 
         assert event == expected
 
-    def test_normalization_from_timestamp_with_collision_without_allow_override_fails(
-        self,
-    ):
+    def test_normalization_from_timestamp_with_collision_without_allow_override_fails(self, caplog):
         event = {
             "@timestamp": "2200-02-01T16:19:22Z",
             "winlog": {
@@ -1055,6 +1047,7 @@ class TestNormalizer(BaseProcessorTestCase):
         }
 
         expected = copy.deepcopy(event)
+        expected.update({"tags": ["_normalizer_failure"]})
 
         rule = {
             "filter": "winlog.event_id: 123456789",
@@ -1072,14 +1065,9 @@ class TestNormalizer(BaseProcessorTestCase):
         }
 
         self._load_specific_rule(rule)
-        with pytest.raises(
-            ProcessingWarning,
-            match=r"ProcessingWarning: \(Test Instance Name - The following fields could not be "
-            r"written, because one or more subfields existed and could not be extended: "
-            r"@timestamp\)",
-        ):
+        with caplog.at_level(logging.WARNING):
             self.object.process(event)
-
+        assert re.match(".*FieldExistsWarning.*", caplog.text)
         assert event == expected
 
     def test_normalization_with_replace_html_entity(self):
@@ -1149,7 +1137,7 @@ class TestNormalizer(BaseProcessorTestCase):
 
         assert len(match_cnt_files) == 1
 
-        now = arrow.now()
+        now = TimeParser.now()
         date = now.date()
         match_file_name = match_cnt_files[0]
 
