@@ -8,7 +8,6 @@ from tests.unit.processor.base import BaseProcessorTestCase
 
 
 class TestSelectiveExtractor(BaseProcessorTestCase):
-
     CONFIG = {
         "type": "selective_extractor",
         "specific_rules": ["tests/testdata/unit/selective_extractor/rules/specific"],
@@ -16,7 +15,6 @@ class TestSelectiveExtractor(BaseProcessorTestCase):
     }
 
     def test_selective_extractor_does_not_change_orig_doc(self):
-        assert self.object.metrics.number_of_processed_events == 0
         document = {"user": "test_user", "other": "field"}
         exp_document = {"user": "test_user", "other": "field"}
 
@@ -37,10 +35,8 @@ class TestSelectiveExtractor(BaseProcessorTestCase):
             {
                 "filter": field_name,
                 "selective_extractor": {
-                    "extract": {
-                        "extracted_field_list": [field_name],
-                        "target_topic": "my topic",
-                    },
+                    "source_fields": [field_name],
+                    "outputs": [{"kafka": "topic"}],
                 },
             }
         )
@@ -53,32 +49,48 @@ class TestSelectiveExtractor(BaseProcessorTestCase):
         else:
             assert False
 
-    def test_process_returns_selective_extractor_topic(self):
+    def test_process_returns_selective_extractor_target_topic(self):
         field_name = f"{uuid.uuid4()}"
-        rule = SelectiveExtractorRule._create_from_dict(
-            {
-                "filter": field_name,
-                "selective_extractor": {
-                    "extract": {
-                        "extracted_field_list": [field_name],
-                        "target_topic": "my topic",
-                    },
-                },
-            }
-        )
-        self.object._specific_tree.add_rule(rule)
+        rule = {
+            "filter": field_name,
+            "selective_extractor": {
+                "source_fields": [field_name],
+                "outputs": [{"opensearch": "my topic"}],
+            },
+        }
+        self._load_specific_rule(rule)
         document = {field_name: "test_message", "other": "field"}
         result = self.object.process(document)
-        for _, topic in result:
-            if topic == "my topic":
-                break
-        else:
-            assert False
+        output = result[0][1][0]
+        assert "my topic" in output.values()
+
+    def test_process_returns_selective_extractor_target_output(self):
+        field_name = f"{uuid.uuid4()}"
+        rule = {
+            "filter": field_name,
+            "selective_extractor": {
+                "source_fields": [field_name],
+                "outputs": [{"opensearch": "index"}],
+            },
+        }
+        self._load_specific_rule(rule)
+        document = {field_name: "test_message", "other": "field"}
+        result = self.object.process(document)
+        output = result[0][1][0]
+        assert "opensearch" in output.keys()
 
     def test_process_returns_extracted_fields(self):
         document = {"message": "test_message", "other": "field"}
+        rule = {
+            "filter": "message",
+            "selective_extractor": {
+                "source_fields": ["message"],
+                "outputs": [{"opensearch": "index"}],
+            },
+        }
+        self._load_specific_rule(rule)
         result = self.object.process(document)
-        for filtered_event, _ in result:
+        for filtered_event, *_ in result:
             if filtered_event[0] == {"message": "test_message"}:
                 break
         else:
@@ -105,31 +117,64 @@ class TestSelectiveExtractor(BaseProcessorTestCase):
             mock_apply_rules.assert_called()
 
     def test_process_extracts_dotted_fields(self):
-        rule = SelectiveExtractorRule._create_from_dict(
-            {
-                "filter": "message",
-                "selective_extractor": {
-                    "extract": {
-                        "extracted_field_list": ["other.message", "message"],
-                        "target_topic": "my topic",
-                    },
-                },
-            }
-        )
-        self.object._specific_tree.add_rule(rule)
+        rule = {
+            "filter": "message",
+            "selective_extractor": {
+                "source_fields": ["other.message", "message"],
+                "outputs": [{"opensearch": "index"}],
+            },
+        }
+        self._load_specific_rule(rule)
         document = {"message": "test_message", "other": {"message": "my message value"}}
         result = self.object.process(document)
 
-        for extracted_event, _ in result:
+        for extracted_event, *_ in result:
             if extracted_event[0].get("other", {}).get("message") is not None:
                 break
         else:
             assert False, f"other.message not in {result}"
 
     def test_process_clears_internal_filtered_events_list_before_every_event(self):
-        assert len(self.object._filtered_events) == 0
+        assert len(self.object._extra_data) == 0
         document = {"message": "test_message", "other": {"message": "my message value"}}
         _ = self.object.process(document)
-        assert len(self.object._filtered_events) == 1
+        assert len(self.object._extra_data) == 1
         _ = self.object.process(document)
-        assert len(self.object._filtered_events) == 1
+        assert len(self.object._extra_data) == 1
+
+    def test_process_extracts_dotted_fields_complains_on_missing_fields(self):
+        rule = {
+            "filter": "message",
+            "selective_extractor": {
+                "source_fields": ["other.message", "not.exists", "message"],
+                "outputs": [{"opensearch": "index"}],
+                "ignore_missing_fields": False,
+            },
+        }
+        self._load_specific_rule(rule)
+        document = {"message": "test_message", "other": {"message": "my message value"}}
+        expected = {
+            "message": "test_message",
+            "other": {"message": "my message value"},
+            "tags": ["_selective_extractor_missing_field_warning"],
+        }
+        self.object.process(document)
+        assert document == expected
+
+    def test_process_extracts_dotted_fields_and_ignores_missing_fields(self):
+        rule = {
+            "filter": "message",
+            "selective_extractor": {
+                "source_fields": ["other.message", "message", "not.exists"],
+                "outputs": [{"opensearch": "index"}],
+                "ignore_missing_fields": True,
+            },
+        }
+        self._load_specific_rule(rule)
+        document = {"message": "test_message", "other": {"message": "my message value"}}
+        expected = {
+            "message": "test_message",
+            "other": {"message": "my message value"},
+        }
+        self.object.process(document)
+        assert document == expected
