@@ -1,4 +1,6 @@
 # pylint: disable=missing-module-docstring
+import logging
+import re
 from copy import deepcopy
 
 import pytest
@@ -9,7 +11,6 @@ from tests.unit.processor.base import BaseProcessorTestCase
 
 
 class TestTemplateReplacer(BaseProcessorTestCase):
-
     CONFIG = {
         "type": "template_replacer",
         "generic_rules": ["tests/testdata/unit/template_replacer/rules/generic"],
@@ -33,7 +34,6 @@ class TestTemplateReplacer(BaseProcessorTestCase):
         return self.CONFIG.get("specific_rules")
 
     def test_replace_message_via_template(self):
-        assert self.object.metrics.number_of_processed_events == 0
         document = {
             "winlog": {"channel": "System", "provider_name": "Test", "event_id": 123},
             "message": "foo",
@@ -45,7 +45,6 @@ class TestTemplateReplacer(BaseProcessorTestCase):
         assert document["message"] == "Test %1 Test %2"
 
     def test_replace_non_existing_message_via_template(self):
-        assert self.object.metrics.number_of_processed_events == 0
         document = {"winlog": {"channel": "System", "provider_name": "Test", "event_id": 123}}
 
         self.object.process(document)
@@ -54,7 +53,6 @@ class TestTemplateReplacer(BaseProcessorTestCase):
         assert document["message"] == "Test %1 Test %2"
 
     def test_replace_with_additional_hyphen(self):
-        assert self.object.metrics.number_of_processed_events == 0
         document = {
             "winlog": {"channel": "System", "provider_name": "Test-Test", "event_id": 123},
             "message": "foo",
@@ -66,8 +64,6 @@ class TestTemplateReplacer(BaseProcessorTestCase):
         assert document["message"] == "Test %1 Test %2 Test %3"
 
     def test_replace_fails_because_it_does_not_map_to_anything(self):
-        assert self.object.metrics.number_of_processed_events == 0
-
         document = {
             "winlog": {"channel": "System", "provider_name": "Test-Test", "event_id": 923},
             "message": "foo",
@@ -86,7 +82,6 @@ class TestTemplateReplacer(BaseProcessorTestCase):
         config = deepcopy(self.CONFIG)
         config.get("pattern").update({"target_field": "dotted.message"})
         self.object = Factory.create({"test instance": config}, self.logger)
-        assert self.object.metrics.number_of_processed_events == 0
         document = {
             "winlog": {"channel": "System", "provider_name": "Test", "event_id": 123},
             "dotted": {"message": "foo"},
@@ -102,7 +97,6 @@ class TestTemplateReplacer(BaseProcessorTestCase):
         config = deepcopy(self.CONFIG)
         config.get("pattern").update({"target_field": "dotted.message"})
         self.object = Factory.create({"test instance": config}, self.logger)
-        assert self.object.metrics.number_of_processed_events == 0
         document = {"winlog": {"channel": "System", "provider_name": "Test", "event_id": 123}}
 
         self.object.process(document)
@@ -115,7 +109,6 @@ class TestTemplateReplacer(BaseProcessorTestCase):
         config = deepcopy(self.CONFIG)
         config.get("pattern").update({"target_field": "dotted.message"})
         self.object = Factory.create({"test instance": config}, self.logger)
-        assert self.object.metrics.number_of_processed_events == 0
         document = {
             "winlog": {"channel": "System", "provider_name": "Test", "event_id": 123},
             "dotted": {"bar": "foo"},
@@ -132,7 +125,6 @@ class TestTemplateReplacer(BaseProcessorTestCase):
         config = deepcopy(self.CONFIG)
         config.get("pattern").update({"target_field": "dotted.message"})
         self.object = Factory.create({"test instance": config}, self.logger)
-        assert self.object.metrics.number_of_processed_events == 0
         document = {
             "winlog": {"channel": "System", "provider_name": "Test", "event_id": 123},
             "dotted": {"message": {"foo": "bar"}},
@@ -144,22 +136,18 @@ class TestTemplateReplacer(BaseProcessorTestCase):
         assert document["dotted"].get("message")
         assert document["dotted"]["message"] == "Test %1 Test %2"
 
-    def test_replace_incompatible_existing_dotted_message_parent_via_template(self):
+    def test_replace_incompatible_existing_dotted_message_parent_via_template(self, caplog):
         config = deepcopy(self.CONFIG)
         config.get("pattern").update({"target_field": "dotted.message"})
         self.object = Factory.create({"test instance": config}, self.logger)
-        assert self.object.metrics.number_of_processed_events == 0
         document = {
             "winlog": {"channel": "System", "provider_name": "Test", "event_id": 123},
             "dotted": "foo",
         }
 
-        with pytest.raises(
-            TemplateReplacerError,
-            match="Parent field 'dotted' of target field 'dotted.message' exists "
-            "and is not a dict!",
-        ):
+        with caplog.at_level(logging.WARNING):
             self.object.process(document)
+        assert re.match(".*FieldExistsWarning.*", caplog.text)
 
     def test_replace_fails_with_invalid_template(self):
         config = deepcopy(self.CONFIG)
