@@ -7,19 +7,18 @@ from random import sample
 from string import ascii_letters
 from unittest import mock
 
-from pytest import raises, mark
+from pytest import mark, raises
 
 from logprep.abc.input import Input
 from logprep.factory import Factory
 from logprep.factory_error import (
-    InvalidConfigurationError,
-    UnknownComponentTypeError,
-    NoTypeSpecifiedError,
     InvalidConfigSpecificationError,
+    InvalidConfigurationError,
+    NoTypeSpecifiedError,
+    UnknownComponentTypeError,
 )
 from logprep.processor.clusterer.processor import Clusterer
 from logprep.processor.labeler.processor import Labeler
-from logprep.processor.normalizer.processor import Normalizer
 from logprep.processor.pseudonymizer.processor import Pseudonymizer
 from tests.testdata.metadata import path_to_schema, path_to_single_rule
 
@@ -84,9 +83,8 @@ def test_create_pseudonymizer_returns_pseudonymizer_processor():
                 "specific_rules": ["tests/testdata/unit/pseudonymizer/rules/specific"],
                 "generic_rules": ["tests/testdata/unit/pseudonymizer/rules/generic"],
                 "regex_mapping": "tests/testdata/unit/pseudonymizer/rules/regex_mapping.yml",
-                "pseudonyms_topic": "pseudonyms",
+                "outputs": [{"kafka": "topic"}],
                 "max_cached_pseudonyms": 1000000,
-                "max_caching_days": 1,
             }
         },
         logger,
@@ -95,22 +93,6 @@ def test_create_pseudonymizer_returns_pseudonymizer_processor():
     assert isinstance(processor, Pseudonymizer)
 
 
-def test_create_normalizer_returns_normalizer_processor():
-    processor = Factory.create(
-        {
-            "normalizer": {
-                "type": "normalizer",
-                "specific_rules": ["tests/testdata/unit/normalizer/rules/specific"],
-                "generic_rules": ["tests/testdata/unit/normalizer/rules/generic"],
-                "regex_mapping": "tests/testdata/unit/normalizer/regex_mapping.yml",
-            }
-        },
-        logger,
-    )
-
-    assert isinstance(processor, Normalizer)
-
-
 def test_create_clusterer_returns_clusterer_processor():
     processor = Factory.create(
         {
@@ -152,6 +134,87 @@ def test_create_labeler_creates_labeler_processor():
     assert isinstance(processor, Labeler)
 
 
+def test_creates_calculator_with_inline_rules():
+    processor = Factory.create(
+        {
+            "calculator": {
+                "type": "calculator",
+                "generic_rules": [
+                    {
+                        "filter": "message",
+                        "calculator": {"target_field": "target", "calc": "1 + 1"},
+                    },
+                ],
+                "specific_rules": [
+                    {
+                        "filter": "message",
+                        "calculator": {"target_field": "target", "calc": "1 + 3"},
+                    },
+                ],
+            }
+        },
+        logger,
+    )
+    assert len(processor._generic_rules) == 1
+    assert len(processor._specific_rules) == 1
+
+
+def test_creates_calculator_with_inline_rules_and_files():
+    processor = Factory.create(
+        {
+            "calculator": {
+                "type": "calculator",
+                "generic_rules": [
+                    {
+                        "filter": "message1",
+                        "calculator": {"target_field": "target", "calc": "1 + 1"},
+                    },
+                    "tests/testdata/unit/calculator/generic_rules/calculator.json",
+                ],
+                "specific_rules": [
+                    {
+                        "filter": "message",
+                        "calculator": {"target_field": "target", "calc": "1 + 3"},
+                    },
+                    "tests/testdata/unit/calculator/specific_rules/calculator.json",
+                ],
+            }
+        },
+        logger,
+    )
+    assert len(processor._generic_rules) == 2
+    assert len(processor._specific_rules) == 2
+    assert processor._generic_rules[0].filter_str == "message1: *"
+    assert processor._generic_rules[1].filter_str == "(field1: * AND field2: *)"
+
+
+def test_creates_calculator_with_inline_rules_and_file_and_directory():
+    processor = Factory.create(
+        {
+            "calculator": {
+                "type": "calculator",
+                "generic_rules": [
+                    {
+                        "filter": "message",
+                        "calculator": {"target_field": "target", "calc": "1 + 1"},
+                    },
+                    "tests/testdata/unit/calculator/generic_rules/",
+                ],
+                "specific_rules": [
+                    {
+                        "filter": "message",
+                        "calculator": {"target_field": "target", "calc": "1 + 3"},
+                    },
+                    "tests/testdata/unit/calculator/specific_rules/calculator.json",
+                ],
+            }
+        },
+        logger,
+    )
+    assert len(processor._generic_rules) == 2
+    assert len(processor._specific_rules) == 2
+
+
 def test_dummy_input_creates_dummy_input_connector():
     processor = Factory.create(
         {"labelername": {"type": "dummy_input", "documents": [{}, {}]}},
