@@ -1,30 +1,30 @@
 # pylint: disable=missing-docstring
 # pylint: disable=protected-access
+import os
 import sys
 from pathlib import Path
 from unittest import mock
 
 import pytest
-import responses
 import requests
+import responses
 from yaml import safe_load
 
 from logprep import run_logprep
 from logprep._version import get_versions
 from logprep.run_logprep import DEFAULT_LOCATION_CONFIG
 from logprep.util.configuration import InvalidConfigurationError
-from logprep.util.getter import GetterNotFoundError
 
 
 class TestRunLogprep:
     @mock.patch("logprep.run_logprep._run_logprep")
-    def test_main_calls_run_logprep_with_quickstart_config(self, mock_run_logprep):
+    def test_main_calls_run_logprep_with_test_config(self, mock_run_logprep):
         with mock.patch(
             "sys.argv",
             [
                 "logprep",
                 "--disable-logging",
-                "quickstart/exampledata/config/pipeline.yml",
+                "tests/testdata/config/config.yml",
             ],
         ):
             run_logprep.main()
@@ -38,7 +38,7 @@ class TestRunLogprep:
                 "logprep",
                 "--disable-logging",
                 "--validate-rules",
-                "quickstart/exampledata/config/pipeline.yml",
+                "tests/testdata/config/config.yml",
             ],
         ):
             with pytest.raises(SystemExit):
@@ -52,32 +52,28 @@ class TestRunLogprep:
                 "logprep",
                 "--disable-logging",
                 "--validate-rules",
-                "file://quickstart/exampledata/config/pipeline.yml",
+                "file://tests/testdata/config/config.yml",
             ],
         ):
             with pytest.raises(SystemExit, match="0"):
                 run_logprep.main()
 
-    def test_raises_getter_error_for_not_existing_protocol(self):
+    def test_exits_after_getter_error_for_not_existing_protocol(self):
         with mock.patch(
             "sys.argv",
             [
                 "logprep",
                 "--disable-logging",
                 "--validate-rules",
-                "almighty_protocol://quickstart/exampledata/config/pipeline.yml",
+                "almighty_protocol://tests/testdata/config/config.yml",
             ],
         ):
-            with pytest.raises(
-                GetterNotFoundError, match="No getter for protocol 'almighty_protocol'"
-            ):
+            with pytest.raises(SystemExit, match="1"):
                 run_logprep.main()
 
     @responses.activate
     def test_gets_config_from_https(self):
-        pipeline_config = Path("quickstart/exampledata/config/pipeline.yml").read_text(
-            encoding="utf8"
-        )
+        pipeline_config = Path("tests/testdata/config/config.yml").read_text(encoding="utf8")
         responses.add(responses.GET, "https://does.not.exits/pipline.yml", pipeline_config)
         with mock.patch(
             "sys.argv",
@@ -91,21 +87,6 @@ class TestRunLogprep:
             with pytest.raises(SystemExit, match="0"):
                 run_logprep.main()
 
-    def test_quickstart_rules_are_valid(self):
-        """ensures the quickstart rules are valid"""
-        with mock.patch(
-            "sys.argv",
-            [
-                "logprep",
-                "--disable-logging",
-                "--validate-rules",
-                "quickstart/exampledata/config/pipeline.yml",
-            ],
-        ):
-            with pytest.raises(SystemExit) as e_info:
-                run_logprep.main()
-        assert e_info.value.code == 0
-
     def test_version_arg_prints_logprep_version_without_config_argument(self, capsys):
         with mock.patch("sys.argv", ["logprep", "--version"]):
             with pytest.raises(SystemExit):
@@ -120,7 +101,7 @@ class TestRunLogprep:
         )
 
     def test_version_arg_prints_also_config_version_if_version_key_is_found(self, capsys):
-        config_path = "quickstart/exampledata/config/pipeline.yml"
+        config_path = "tests/testdata/config/config.yml"
         with mock.patch("sys.argv", ["logprep", "--version", config_path]):
             with pytest.raises(SystemExit):
                 run_logprep.main()
@@ -137,10 +118,10 @@ class TestRunLogprep:
 
     @responses.activate
     def test_version_arg_prints_with_http_config(self, capsys):
-        config_path = "quickstart/exampledata/config/pipeline.yml"
+        config_path = "tests/testdata/config/config.yml"
         responses.add(
             responses.GET,
-            "http://localhost:32000/quickstart/exampledata/config/pipeline.yml",
+            "http://localhost:32000/tests/testdata/config/config.yml",
             Path(config_path).read_text(encoding="utf8"),
         )
         with mock.patch(
@@ -155,28 +136,34 @@ class TestRunLogprep:
         expected_lines = (
             f"python version:          {sys.version.split()[0]}\n"
             f"logprep version:         {get_versions()['version']}\n"
-            f"configuration version:   {configuration['version']}, http://localhost:32000/{config_path}"
+            f"configuration version:   {configuration['version']},"
+            f" http://localhost:32000/{config_path}"
         )
         assert lines == expected_lines
 
     @responses.activate
     def test_version_arg_prints_with_http_config_without_exposing_secret_data(self, capsys):
-        config_path = "quickstart/exampledata/config/pipeline.yml"
+        config_path = "tests/testdata/config/config.yml"
+        mock_env = {
+            "LOGPREP_CONFIG_ATUH_USERNAME": "username",
+            "LOGPREP_CONFIG_ATUH_PASSWORD": "password",
+        }
         responses.add(
             responses.GET,
-            "http://localhost:32000/quickstart/exampledata/config/pipeline.yml",
+            "http://localhost:32000/tests/testdata/config/config.yml",
             Path(config_path).read_text(encoding="utf8"),
         )
-        with mock.patch(
-            "sys.argv",
-            [
-                "logprep",
-                "--version",
-                f"http://username:password@localhost:32000/{config_path}",
-            ],
-        ):
-            with pytest.raises(SystemExit):
-                run_logprep.main()
+        with mock.patch("os.environ", mock_env):
+            with mock.patch(
+                "sys.argv",
+                [
+                    "logprep",
+                    "--version",
+                    f"http://localhost:32000/{config_path}",
+                ],
+            ):
+                with pytest.raises(SystemExit):
+                    run_logprep.main()
         captured = capsys.readouterr()
         lines = captured.out.strip()
         with open(config_path, "r", encoding="utf-8") as file:
@@ -184,7 +171,8 @@ class TestRunLogprep:
         expected_lines = (
             f"python version:          {sys.version.split()[0]}\n"
             f"logprep version:         {get_versions()['version']}\n"
-            f"configuration version:   {configuration['version']}, http://localhost:32000/{config_path}"
+            f"configuration version:   {configuration['version']},"
+            f" http://localhost:32000/{config_path}"
         )
         assert lines == expected_lines
 
@@ -216,7 +204,7 @@ class TestRunLogprep:
     @mock.patch("logprep.runner.Runner.load_configuration")
     @mock.patch("logprep.runner.Runner.start")
     def test_main_loads_configuration_and_starts_runner(self, mock_start, mock_load):
-        config_path = "quickstart/exampledata/config/pipeline.yml"
+        config_path = "tests/testdata/config/config.yml"
         with mock.patch("sys.argv", ["logprep", config_path]):
             run_logprep.main()
         mock_load.assert_called_with(config_path)
@@ -226,15 +214,16 @@ class TestRunLogprep:
     @mock.patch("logprep.runner.Runner.stop")
     def test_main_calls_runner_stop_on_any_exception(self, mock_stop, mock_start):
         mock_start.side_effect = Exception
-        config_path = "quickstart/exampledata/config/pipeline.yml"
-        with mock.patch("sys.argv", ["logprep", config_path]):
-            run_logprep.main()
+        config_path = "tests/testdata/config/config.yml"
+        with pytest.raises(SystemExit):
+            with mock.patch("sys.argv", ["logprep", config_path]):
+                run_logprep.main()
         mock_stop.assert_called()
 
     def test_logprep_exits_if_logger_can_not_be_created(self):
-        with mock.patch("logprep.run_logprep.AggregatingLogger.create") as mock_create:
+        with mock.patch("logprep.run_logprep.Configuration.get") as mock_create:
             mock_create.side_effect = BaseException
-            config_path = "quickstart/exampledata/config/pipeline.yml"
+            config_path = "tests/testdata/config/config.yml"
             with mock.patch("sys.argv", ["logprep", config_path]):
                 with pytest.raises(SystemExit):
                     run_logprep.main()
@@ -242,7 +231,7 @@ class TestRunLogprep:
     def test_logprep_exits_on_invalid_configuration(self):
         with mock.patch("logprep.util.configuration.Configuration.verify") as mock_verify:
             mock_verify.side_effect = InvalidConfigurationError
-            config_path = "quickstart/exampledata/config/pipeline.yml"
+            config_path = "tests/testdata/config/config.yml"
             with mock.patch("sys.argv", ["logprep", config_path]):
                 with pytest.raises(SystemExit):
                     run_logprep.main()
@@ -250,7 +239,7 @@ class TestRunLogprep:
     def test_logprep_exits_on_any_exception_during_verify(self):
         with mock.patch("logprep.util.configuration.Configuration.verify") as mock_verify:
             mock_verify.side_effect = Exception
-            config_path = "quickstart/exampledata/config/pipeline.yml"
+            config_path = "tests/testdata/config/config.yml"
             with mock.patch("sys.argv", ["logprep", config_path]):
                 with pytest.raises(SystemExit):
                     run_logprep.main()
@@ -261,3 +250,23 @@ class TestRunLogprep:
             with mock.patch("sys.argv", ["logprep", "http://localhost/does-not-exists"]):
                 with pytest.raises(SystemExit):
                     run_logprep.main()
+
+    @mock.patch("logprep.util.configuration.Configuration.verify")
+    def test_logprep_verifies_config(self, mock_verify):
+        with mock.patch(
+            "sys.argv",
+            ["logprep", "tests/testdata/config/config.yml", "--verify-config"],
+        ):
+            run_logprep.main()
+        mock_verify.assert_called()
+
+    @mock.patch("logprep.util.configuration.Configuration.verify")
+    def test_logprep_exits_on_verify_config_with_invalid_config(self, mock_verify):
+        mock_verify.side_effect = InvalidConfigurationError
+        with mock.patch(
+            "sys.argv",
+            ["logprep", "tests/testdata/config/config.yml", "--verify-config"],
+        ):
+            with pytest.raises(SystemExit):
+                run_logprep.main()
+        mock_verify.assert_called()
