@@ -1,38 +1,52 @@
 # pylint: disable=missing-docstring
 # pylint: disable=protected-access
 # pylint: disable=line-too-long
+import os
+import re
 from copy import deepcopy
 from logging import getLogger
-import re
 from pathlib import Path
 from unittest import mock
 
 import pytest
 
 from logprep.util.configuration import (
-    InvalidConfigurationError,
     Configuration,
-    IncalidMetricsConfigurationError,
-    RequiredConfigurationKeyMissingError,
+    InvalidConfigurationError,
     InvalidConfigurationErrors,
-    InvalidProcessorConfigurationError,
     InvalidInputConnectorConfigurationError,
-    InvalidOutputConnectorConfigurationError,
+    InvalidProcessorConfigurationError,
+    RequiredConfigurationKeyMissingError,
 )
+from logprep.util.getter import GetterFactory
+from logprep.util.json_handling import dump_config_as_file
 from tests.testdata.metadata import path_to_config
 
 logger = getLogger()
 
 
 class TestConfiguration:
-
     config: dict
 
     def setup_method(self):
         self.config = Configuration.create_from_yaml(path_to_config)
 
+    def teardown_method(self):
+        if "LOGPREP_VERSION" in os.environ:
+            os.environ.pop("LOGPREP_VERSION")
+        if "LOGPREP_PROCESS_COUNT" in os.environ:
+            os.environ.pop("LOGPREP_PROCESS_COUNT")
+        if "LOGPREP_LOG_LEVEL" in os.environ:
+            os.environ.pop("LOGPREP_LOG_LEVEL")
+        if "LOGPREP_PIPELINE" in os.environ:
+            os.environ.pop("LOGPREP_PIPELINE")
+        if "LOGPREP_OUTPUT" in os.environ:
+            os.environ.pop("LOGPREP_OUTPUT")
+        if "LOGPREP_INPUT" in os.environ:
+            os.environ.pop("LOGPREP_INPUT")
+
     def assert_fails_when_replacing_key_with_value(self, key, value, expected_message):
-        config = Configuration(deepcopy(self.config))
+        config = Configuration.create_from_yaml(path_to_config)
 
         parent = config
         if not isinstance(key, str):
@@ -58,8 +72,8 @@ class TestConfiguration:
     def test_verify_passes_for_valid_configuration(self):
         try:
             self.config.verify(logger)
-        except InvalidConfigurationError:
-            pytest.fail("The verification should pass for a valid configuration.")
+        except InvalidConfigurationError as error:
+            pytest.fail(f"The verification should pass for a valid configuration.: {error}")
 
     def test_verify_pipeline_only_passes_for_valid_configuration(self):
         try:
@@ -68,7 +82,10 @@ class TestConfiguration:
             pytest.fail("The verification should pass for a valid configuration.")
 
     def test_verify_fails_on_missing_required_value(self):
+        not_required_keys = ["version"]
         for key in list(self.config.keys()):
+            if key in not_required_keys:
+                continue
             config = deepcopy(self.config)
             del config[key]
 
@@ -116,151 +133,13 @@ class TestConfiguration:
         [
             (
                 "valid configuration",
-                {
-                    "metrics": {
-                        "period": 10,
-                        "enabled": True,
-                        "cumulative": True,
-                        "aggregate_processes": True,
-                        "measure_time": {"enabled": True, "append_to_event": False},
-                        "targets": [
-                            {"prometheus": {"port": 8000}},
-                            {
-                                "file": {
-                                    "path": "./logs/status.json",
-                                    "rollover_interval": 86400,
-                                    "backup_count": 10,
-                                }
-                            },
-                        ],
-                    }
-                },
+                {"metrics": {"enabled": True, "port": 8000}},
                 None,
             ),
             (
-                "key period is missing",
-                {
-                    "metrics": {
-                        "enabled": True,
-                        "cumulative": True,
-                        "aggregate_processes": True,
-                        "measure_time": {"enabled": True, "append_to_event": False},
-                        "targets": [
-                            {"prometheus": {"port": 8000}},
-                            {
-                                "file": {
-                                    "path": "./logs/status.json",
-                                    "rollover_interval": 86400,
-                                    "backup_count": 10,
-                                }
-                            },
-                        ],
-                    }
-                },
-                RequiredConfigurationKeyMissingError,
-            ),
-            (
-                "empty target",
-                {
-                    "metrics": {
-                        "period": 10,
-                        "enabled": True,
-                        "cumulative": True,
-                        "aggregate_processes": True,
-                        "measure_time": {"enabled": True, "append_to_event": False},
-                        "targets": [],
-                    }
-                },
-                IncalidMetricsConfigurationError,
-            ),
-            (
-                "unkown target",
-                {
-                    "metrics": {
-                        "period": 10,
-                        "enabled": True,
-                        "cumulative": True,
-                        "aggregate_processes": True,
-                        "measure_time": {"enabled": True, "append_to_event": False},
-                        "targets": [{"webserver": {"does-not": "exist"}}],
-                    }
-                },
-                IncalidMetricsConfigurationError,
-            ),
-            (
-                "missing key in prometheus target config",
-                {
-                    "metrics": {
-                        "period": 10,
-                        "enabled": True,
-                        "cumulative": True,
-                        "aggregate_processes": True,
-                        "measure_time": {"enabled": True, "append_to_event": False},
-                        "targets": [{"prometheus": {"wrong": "key"}}],
-                    }
-                },
-                RequiredConfigurationKeyMissingError,
-            ),
-            (
-                "missing key in file target config",
-                {
-                    "metrics": {
-                        "period": 10,
-                        "enabled": True,
-                        "cumulative": True,
-                        "aggregate_processes": True,
-                        "measure_time": {"enabled": True, "append_to_event": False},
-                        "targets": [
-                            {
-                                "file": {
-                                    "rollover_interval": 86400,
-                                    "backup_count": 10,
-                                }
-                            },
-                        ],
-                    }
-                },
-                RequiredConfigurationKeyMissingError,
-            ),
-            (
-                "valid configuration",
-                {
-                    "metrics": {
-                        "period": 10,
-                        "enabled": True,
-                        "cumulative": True,
-                        "aggregate_processes": True,
-                        "measure_time": {"enabled": True, "append_to_event": False},
-                        "targets": [
-                            {"prometheus": {"port": 8000}},
-                            {"file": {}},
-                        ],
-                    }
-                },
-                RequiredConfigurationKeyMissingError,
-            ),
-            (
-                "measure_time enabled key is missing",
-                {
-                    "metrics": {
-                        "period": 10,
-                        "enabled": True,
-                        "cumulative": True,
-                        "aggregate_processes": True,
-                        "measure_time": {"append_to_event": False},
-                        "targets": [
-                            {"prometheus": {"port": 8000}},
-                            {
-                                "file": {
-                                    "path": "./logs/status.json",
-                                    "rollover_interval": 86400,
-                                    "backup_count": 10,
-                                }
-                            },
-                        ],
-                    }
-                },
-                RequiredConfigurationKeyMissingError,
+                "invalid datatype in port",
+                {"metrics": {"enabled": True, "port": "8000"}},
+                None,
             ),
         ],
     )
@@ -438,6 +317,51 @@ class TestConfiguration:
                     )
                 ],
             ),
+            (
+                "processor error for config and output does not exists",
+                {
+                    "output": {},
+                    "pipeline": [
+                        {
+                            "labelername": {
+                                "type": "labeler",
+                                "schema": "quickstart/exampledata/rules/labeler/schema.json",
+                                "include_parent_labels": "on",
+                                "specific_rules": ["quickstart/exampledata/rules/labeler/specific"],
+                                "generic_rules": ["quickstart/exampledata/rules/labeler/generic"],
+                                "some unknown option": "foo",
+                            }
+                        },
+                        {
+                            "pseudo": {
+                                "type": "pseudonymizer",
+                                "outputs": [{"kafka": "topic"}],
+                                "pubkey_analyst": "tests/testdata/unit/pseudonymizer/example_analyst_pub.pem",
+                                "pubkey_depseudo": "tests/testdata/unit/pseudonymizer/example_depseudo_pub.pem",
+                                "hash_salt": "a_secret_tasty_ingredient",
+                                "specific_rules": [
+                                    "tests/testdata/unit/pseudonymizer/rules/specific/"
+                                ],
+                                "generic_rules": [
+                                    "tests/testdata/unit/pseudonymizer/rules/generic/"
+                                ],
+                                "regex_mapping": "tests/testdata/unit/pseudonymizer/rules/regex_mapping.yml",
+                                "max_cached_pseudonyms": 1000000,
+                            }
+                        },
+                    ],
+                },
+                [
+                    (
+                        InvalidProcessorConfigurationError,
+                        "Invalid processor configuration: labelername - Unknown option: 'some unknown option'.",
+                    ),
+                    (
+                        InvalidProcessorConfigurationError,
+                        "Invalid processor configuration: pseudo: output 'kafka' does not exist in logprep outputs",
+                    ),
+                ],
+            ),
         ],
     )
     def test_verify_error(self, config_dict, raised_errors, test_case):
@@ -447,7 +371,7 @@ class TestConfiguration:
             with pytest.raises(InvalidConfigurationErrors) as e_info:
                 config.verify(logger)
             errors_set = [(type(err), str(err)) for err in e_info.value.errors]
-            assert len(raised_errors) == len(errors_set)
+            assert len(raised_errors) == len(errors_set), test_case
             zipped_errors = zip(raised_errors, errors_set)
             for expected_error, raised_error in zipped_errors:
                 assert expected_error[0] == raised_error[0], "error class differ"
@@ -546,48 +470,22 @@ class TestConfiguration:
                     "metrics": {
                         "period": 10,
                         "enabled": True,
-                        "cumulative": True,
-                        "aggregate_processes": True,
-                        "measure_time": {"enabled": True, "append_to_event": False},
-                        "targets": [
-                            {"prometheus": {"port": 8000}},
-                            {
-                                "file": {
-                                    "path": "./logs/status.json",
-                                    "rollover_interval": 86400,
-                                    "backup_count": 10,
-                                }
-                            },
-                        ],
+                        "port": 8000,
                     }
                 },
                 [],
             ),
             (
-                "measure_time enabled key is missing",
+                "metrics enabled",
                 {
                     "metrics": {
-                        "period": 10,
-                        "enabled": True,
-                        "cumulative": True,
-                        "aggregate_processes": True,
-                        "measure_time": {"append_to_event": False},
-                        "targets": [
-                            {"prometheus": {"port": 8000}},
-                            {
-                                "file": {
-                                    "path": "./logs/status.json",
-                                    "rollover_interval": 86400,
-                                    "backup_count": 10,
-                                }
-                            },
-                        ],
+                        "port": 8000,
                     }
                 },
                 [
                     (
                         RequiredConfigurationKeyMissingError,
-                        "Required option is missing: The following option keys for the measure time configs are missing: {'enabled'}",
+                        "Required option is missing: metrics > enabled",
                     )
                 ],
             ),
@@ -597,12 +495,12 @@ class TestConfiguration:
         config = deepcopy(self.config)
         config.update(config_dict)
         if raised_errors is not None:
-            errors = config._perform_verfification_and_get_errors(logger)
+            errors = config._check_for_errors(logger)
             collected_errors = []
             for error in errors:
                 collected_errors += error.errors
             errors_set = [(type(error), str(error)) for error in collected_errors]
-            assert len(raised_errors) == len(errors_set)
+            assert len(raised_errors) == len(errors_set), test_case
             zipped_errors = zip(raised_errors, errors_set)
             for expected_error, raised_error in zipped_errors:
                 assert expected_error[0] == raised_error[0], "error class differ"
@@ -620,12 +518,12 @@ class TestConfiguration:
 
     def test_verify_input_raises_type_error(self):
         config = deepcopy(self.config)
-        del config["input"]["kafka_input"]["bootstrapservers"]
+        del config["input"]["kafka_input"]["topic"]
         with pytest.raises(
             InvalidInputConnectorConfigurationError,
             match=re.escape(
                 "Invalid input connector configuration: Required option(s) are missing: "
-                + "'bootstrapservers'."
+                + "'topic'."
             ),
         ):
             config._verify_input(logger)
@@ -638,14 +536,309 @@ class TestConfiguration:
         ):
             config._verify_output(logger)
 
-    def test_verify_output_raises_type_error(self):
-        config = deepcopy(self.config)
-        del config["output"]["kafka_output"]["bootstrapservers"]
+    def test_patch_yaml_with_json_connectors_inserts_json_input_connector(self, tmp_path):
+        regular_config = GetterFactory.from_string(path_to_config).get_yaml()
+        assert (
+            regular_config.get("input", {}).get("kafka_input", {}).get("type")
+            == "confluentkafka_input"
+        )
+        patched_config_path = Configuration.patch_yaml_with_json_connectors(
+            path_to_config, str(tmp_path)
+        )
+        patched_config = GetterFactory.from_string(patched_config_path).get_yaml()
+        assert patched_config.get("input", {}).get("patched_input", {}).get("type") == "json_input"
+
+    def test_patch_yaml_with_json_connectors_inserts_jsonl_input_connector(self, tmp_path):
+        regular_config = GetterFactory.from_string(path_to_config).get_yaml()
+        assert (
+            regular_config.get("input", {}).get("kafka_input", {}).get("type")
+            == "confluentkafka_input"
+        )
+        input_file_path = tmp_path / "test.jsonl"
+        patched_config_path = Configuration.patch_yaml_with_json_connectors(
+            path_to_config, str(tmp_path), str(input_file_path)
+        )
+        patched_config = GetterFactory.from_string(patched_config_path).get_yaml()
+        assert patched_config.get("input", {}).get("patched_input", {}).get("type") == "jsonl_input"
+
+    def test_patch_yaml_with_json_connectors_keeps_preprocessors(self, tmp_path):
+        regular_config = GetterFactory.from_string(path_to_config).get_yaml()
+        regular_config["input"]["kafka_input"]["preprocessing"] = {
+            "log_arrival_time_target_field": "foo"
+        }
+        test_config_path = str(tmp_path / "test_config.yaml")
+        dump_config_as_file(test_config_path, regular_config)
+        patched_config_path = Configuration.patch_yaml_with_json_connectors(
+            test_config_path, str(tmp_path)
+        )
+        patched_config = GetterFactory.from_string(patched_config_path).get_yaml()
+        assert patched_config.get("input", {}).get("patched_input", {}).get("preprocessing") == {
+            "log_arrival_time_target_field": "foo"
+        }
+
+    def test_patch_yaml_with_json_connectors_inserts_jsonl_output_connector(self, tmp_path):
+        regular_config = GetterFactory.from_string(path_to_config).get_yaml()
+        assert (
+            regular_config.get("output", {}).get("kafka_output", {}).get("type")
+            == "confluentkafka_output"
+        )
+        patched_config_path = Configuration.patch_yaml_with_json_connectors(
+            path_to_config, str(tmp_path)
+        )
+        patched_config = GetterFactory.from_string(patched_config_path).get_yaml()
+        assert (
+            patched_config.get("output", {}).get("patched_output", {}).get("type") == "jsonl_output"
+        )
+
+    def test_patch_yaml_with_json_connectors_set_process_count_to_one(self, tmp_path):
+        regular_config = GetterFactory.from_string(path_to_config).get_yaml()
+        assert regular_config.get("process_count") == 3
+        patched_config_path = Configuration.patch_yaml_with_json_connectors(
+            path_to_config, str(tmp_path)
+        )
+        patched_config = GetterFactory.from_string(patched_config_path).get_yaml()
+        assert patched_config.get("process_count") == 1
+
+    def test_patch_yaml_with_json_connectors_drops_metrics_config(self, tmp_path):
+        regular_config = GetterFactory.from_string(path_to_config).get_yaml()
+        regular_config["metrics"] = {"enabled": "true"}
+        test_config_path = str(tmp_path / "test_config.yaml")
+        dump_config_as_file(test_config_path, regular_config)
+        patched_config_path = Configuration.patch_yaml_with_json_connectors(
+            test_config_path, str(tmp_path)
+        )
+        patched_config = GetterFactory.from_string(patched_config_path).get_yaml()
+        assert patched_config.get("metrics") is None
+
+    def test_config_gets_enriched_by_environment(self, tmp_path):
+        config_path = tmp_path / "pipeline.yml"
+        config_path.write_text(
+            """
+version: $LOGPREP_VERSION
+process_count: $LOGPREP_PROCESS_COUNT
+timeout: 0.1
+logger:
+    level: $LOGPREP_LOG_LEVEL
+$LOGPREP_PIPELINE
+$LOGPREP_INPUT
+$LOGPREP_OUTPUT
+"""
+        )
+        os.environ["LOGPREP_VERSION"] = "1"
+        os.environ["LOGPREP_PROCESS_COUNT"] = "1"
+        os.environ["LOGPREP_LOG_LEVEL"] = "DEBUG"
+        os.environ[
+            "LOGPREP_PIPELINE"
+        ] = """
+pipeline:
+    - labelername:
+        type: labeler
+        schema: quickstart/exampledata/rules/labeler/schema.json
+        include_parent_labels: true
+        specific_rules:
+            - quickstart/exampledata/rules/labeler/specific
+        generic_rules:
+            - quickstart/exampledata/rules/labeler/generic
+"""
+        os.environ[
+            "LOGPREP_OUTPUT"
+        ] = """
+output:
+    kafka:
+        type: confluentkafka_output
+        topic: producer
+        error_topic: producer_error
+        flush_timeout: 30
+        send_timeout: 2
+        kafka_config:
+            bootstrap.servers: "172.21.0.5:9092"
+            acks: "-1"
+            compression.type: "none"
+"""
+        os.environ[
+            "LOGPREP_INPUT"
+        ] = "input:\n    kafka:\n        type: confluentkafka_input\n        topic: consumer\n        kafka_config:\n          bootstrap.servers: localhost:9092\n          group.id: testgroup\n"
+        config = Configuration.create_from_yaml(str(config_path))
+        config.verify(mock.MagicMock())
+
+    def test_config_gets_enriched_by_environment_with_non_existent_variable(self, tmp_path):
+        config_path = tmp_path / "pipeline.yml"
+        config_path.write_text(
+            """
+version: $LOGPREP_VERSION
+process_count: $LOGPREP_PROCESS_COUNT
+timeout: 0.1
+logger:
+    level: $LOGPREP_LOG_LEVEL
+$LOGPREP_I_DO_NOT_EXIST
+$LOGPREP_PIPELINE
+$LOGPREP_INPUT
+$LOGPREP_OUTPUT
+"""
+        )
+        os.environ["LOGPREP_VERSION"] = "1"
+        os.environ["LOGPREP_PROCESS_COUNT"] = "1"
+        os.environ["LOGPREP_LOG_LEVEL"] = "DEBUG"
+        os.environ[
+            "LOGPREP_PIPELINE"
+        ] = """
+pipeline:
+    - labelername:
+        type: labeler
+        schema: quickstart/exampledata/rules/labeler/schema.json
+        include_parent_labels: true
+        specific_rules:
+            - quickstart/exampledata/rules/labeler/specific
+        generic_rules:
+            - quickstart/exampledata/rules/labeler/generic
+"""
+        os.environ[
+            "LOGPREP_OUTPUT"
+        ] = """
+output:
+    kafka:
+        type: confluentkafka_output
+        topic: producer
+        error_topic: producer_error
+        flush_timeout: 30
+        send_timeout: 2
+        kafka_config:
+            bootstrap.servers: "172.21.0.5:9092"
+            acks: "-1"
+            compression.type: "none"
+"""
+        os.environ[
+            "LOGPREP_INPUT"
+        ] = "input:\n    kafka:\n        type: confluentkafka_input\n        topic: consumer\n"
+        config = Configuration.create_from_yaml(str(config_path))
         with pytest.raises(
-            InvalidOutputConnectorConfigurationError,
-            match=re.escape(
-                "Invalid output connector configuration: Required option(s) are missing: "
-                + "'bootstrapservers'."
-            ),
+            InvalidConfigurationErrors,
+            match=r"Environment variable\(s\) used, but not set: LOGPREP_I_DO_NOT_EXIST",
         ):
-            config._verify_output(logger)
+            config.verify(mock.MagicMock())
+
+    def test_verifies_processor_configs_against_defined_outputs(self):
+        config = Configuration()
+        pipeline = [
+            {
+                "se": {
+                    "type": "selective_extractor",
+                    "specific_rules": ["tests/testdata/unit/selective_extractor/rules/specific"],
+                    "generic_rules": ["tests/testdata/unit/selective_extractor/rules/generic"],
+                }
+            },
+            {
+                "pd": {
+                    "type": "pre_detector",
+                    "generic_rules": ["tests/testdata/unit/pre_detector/rules/generic"],
+                    "specific_rules": ["tests/testdata/unit/pre_detector/rules/specific"],
+                    "outputs": [{"kafka": "pre_detector_alerts"}],
+                    "alert_ip_list_path": "tests/testdata/unit/pre_detector/alert_ips.yml",
+                }
+            },
+            {
+                "pseudo": {
+                    "type": "pseudonymizer",
+                    "outputs": [{"kafka": "topic"}],
+                    "pubkey_analyst": "tests/testdata/unit/pseudonymizer/example_analyst_pub.pem",
+                    "pubkey_depseudo": "tests/testdata/unit/pseudonymizer/example_depseudo_pub.pem",
+                    "hash_salt": "a_secret_tasty_ingredient",
+                    "specific_rules": ["tests/testdata/unit/pseudonymizer/rules/specific/"],
+                    "generic_rules": ["tests/testdata/unit/pseudonymizer/rules/generic/"],
+                    "regex_mapping": "tests/testdata/unit/pseudonymizer/rules/regex_mapping.yml",
+                    "max_cached_pseudonyms": 1000000,
+                }
+            },
+        ]
+        config.update({"pipeline": pipeline, "output": {}})
+        with pytest.raises(InvalidConfigurationErrors) as raised:
+            config._verify_pipeline(logger=logger)
+        assert len(raised.value.errors) == 3
+        for error in raised.value.errors:
+            assert "output 'kafka' does not exist in logprep outputs" in error.args[0]
+
+    def test_verify_pipeline_without_processor_outputs_ignores_processor_output_errors(self):
+        config = Configuration()
+        pipeline = [
+            {
+                "pd": {
+                    "type": "pre_detector",
+                    "generic_rules": ["tests/testdata/unit/pre_detector/rules/generic"],
+                    "specific_rules": ["tests/testdata/unit/pre_detector/rules/specific"],
+                    "outputs": [{"kafka": "pre_detector_alerts"}],
+                    "alert_ip_list_path": "tests/testdata/unit/pre_detector/alert_ips.yml",
+                }
+            },
+        ]
+        config.update({"pipeline": pipeline, "output": {}})
+        try:
+            config.verify_pipeline_without_processor_outputs(logger=logger)
+        except InvalidConfigurationErrors as error:
+            assert False, f"Shouldn't raise output does not exist error: '{error}'"
+
+    def test_duplicate_rule_id_per_processor_raises(self):
+        config = Configuration()
+        pipeline = [
+            {
+                "my dissector": {
+                    "type": "dissector",
+                    "specific_rules": [
+                        {
+                            "filter": "message",
+                            "dissector": {
+                                "id": "same id",
+                                "mapping": {"message": "%{new_field} %{next_field}"},
+                            },
+                        },
+                        {
+                            "filter": "message",
+                            "dissector": {
+                                "id": "same id",
+                                "mapping": {"message": "%{other_field} %{next_field}"},
+                            },
+                        },
+                    ],
+                    "generic_rules": [],
+                }
+            },
+        ]
+        config.update({"pipeline": pipeline, "output": {}})
+        with pytest.raises(InvalidConfigurationErrors) as raised:
+            config._verify_pipeline(logger=logger)
+        assert len(raised.value.errors) == 1
+        for error in raised.value.errors:
+            assert "Duplicate rule id: same id" in error.args[0]
+
+    def test_duplicate_rule_id_in_different_rule_trees_per_processor_raises(self):
+        config = Configuration()
+        pipeline = [
+            {
+                "my dissector": {
+                    "type": "dissector",
+                    "specific_rules": [
+                        {
+                            "filter": "message",
+                            "dissector": {
+                                "id": "same id",
+                                "mapping": {"message": "%{new_field} %{next_field}"},
+                            },
+                        },
+                    ],
+                    "generic_rules": [
+                        {
+                            "filter": "message",
+                            "dissector": {
+                                "id": "same id",
+                                "mapping": {"message": "%{other_field} %{next_field}"},
+                            },
+                        },
+                    ],
+                }
+            },
+        ]
+        config.update({"pipeline": pipeline, "output": {}})
+        with pytest.raises(InvalidConfigurationErrors) as raised:
+            config._verify_pipeline(logger=logger)
+        assert len(raised.value.errors) == 1
+        for error in raised.value.errors:
+            assert "Duplicate rule id: same id" in error.args[0]
