@@ -1,11 +1,9 @@
 # pylint: disable=missing-docstring
-# pylint: disable=no-self-use
 # pylint: disable=attribute-defined-outside-init
 import json
 import logging
 import os
 import tempfile
-from unittest import mock
 
 from logprep.util.rule_dry_runner import DryRunner
 
@@ -15,15 +13,13 @@ class TestRunLogprep:
         config = """
         process_count: 1
         timeout: 0.1
-
         pipeline:
-          - normalizer:
-              type: normalizer
+          - dissector:
+              type: dissector
               specific_rules:
-                - tests/testdata/unit/normalizer/rules/specific/
+                - tests/testdata/unit/dissector/
               generic_rules:
-                - tests/testdata/unit/normalizer/rules/generic/
-              regex_mapping: tests/testdata/unit/normalizer/regex_mapping.yml
+                - tests/testdata/unit/dissector/
           - labelername:
               type: labeler
               schema: tests/testdata/unit/labeler/schemas/schema3.json
@@ -38,20 +34,27 @@ class TestRunLogprep:
               pubkey_depseudo: tests/testdata/unit/pseudonymizer/example_depseudo_pub.pem
               regex_mapping: tests/testdata/unit/pseudonymizer/rules/regex_mapping.yml
               hash_salt: a_secret_tasty_ingredient
-              pseudonyms_topic: pseudonyms
+              outputs:
+                - patched_output: pseudonyms
               specific_rules:
                 - tests/testdata/unit/pseudonymizer/rules/specific/
               generic_rules:
                 - tests/testdata/unit/pseudonymizer/rules/generic/
               max_cached_pseudonyms: 1000000
-              max_caching_days: 1
           - predetectorname:
               type: pre_detector
               specific_rules:
                 - tests/testdata/unit/pre_detector/rules/specific/
               generic_rules:
                 - tests/testdata/unit/pre_detector/rules/generic/
-              pre_detector_topic: sre_topic
+              outputs:
+                - patched_output: sre_topic
+          - selective_extractor:
+              type: selective_extractor
+              specific_rules:
+                - tests/testdata/unit/selective_extractor/rules/specific/
+              generic_rules:
+                - tests/testdata/unit/selective_extractor/rules/generic/
         """
         self.config_path = os.path.join(tempfile.gettempdir(), "dry-run-config.yml")
         with open(self.config_path, "w", encoding="utf8") as config_file:
@@ -61,13 +64,13 @@ class TestRunLogprep:
         os.remove(self.config_path)
 
     def test_dry_run_accepts_json_as_input(self, tmp_path, capsys):
-        test_json = {"winlog": {"event_id": 1111, "event_data": {"test2": "fancy data"}}}
+        test_json = {"message": "123 456"}
         input_json_file = os.path.join(tmp_path, "test_input.json")
         with open(input_json_file, "w", encoding="utf8") as input_file:
             json.dump(test_json, input_file)
 
         dry_runner = DryRunner(
-            dry_run=input_json_file,
+            input_file_path=input_json_file,
             config_path=self.config_path,
             full_output=True,
             use_json=True,
@@ -76,6 +79,7 @@ class TestRunLogprep:
         dry_runner.run()
 
         captured = capsys.readouterr()
+        assert captured.err == ""
         assert "------ PROCESSED EVENT ------" in captured.out
         assert "------ TRANSFORMED EVENTS: 1/1 ------" in captured.out
 
@@ -86,7 +90,7 @@ class TestRunLogprep:
             json.dump(test_json, input_file)
 
         dry_runner = DryRunner(
-            dry_run=input_json_file,
+            input_file_path=input_json_file,
             config_path=self.config_path,
             full_output=True,
             use_json=True,
@@ -95,20 +99,18 @@ class TestRunLogprep:
         dry_runner.run()
 
         captured = capsys.readouterr()
+        assert captured.err == ""
         assert "------ PROCESSED EVENT ------" in captured.out
         assert "------ TRANSFORMED EVENTS: 1/1 ------" in captured.out
 
     def test_dry_run_accepts_jsonl_as_input(self, tmp_path, capsys):
-        test_jsonl = [
-            '{"winlog": {"event_id": 1111, "event_data": {"test2": "fancy data"}}}\n',
-            '{"winlog": {"event_id": 1111, "event_data": {"test2": "more fancy data"}}}',
-        ]
+        test_jsonl = ['{"message": "123 456"}\n', '{"message": "789 012"}']
         input_jsonl_file = os.path.join(tmp_path, "test_input.jsonl")
         with open(input_jsonl_file, "w", encoding="utf8") as input_file:
             input_file.writelines(test_jsonl)
 
         dry_runner = DryRunner(
-            dry_run=input_jsonl_file,
+            input_file_path=input_jsonl_file,
             config_path=self.config_path,
             full_output=True,
             use_json=False,
@@ -117,6 +119,7 @@ class TestRunLogprep:
         dry_runner.run()
 
         captured = capsys.readouterr()
+        assert captured.err == ""
         assert "------ PROCESSED EVENT ------" in captured.out
         assert captured.out.count("------ PROCESSED EVENT ------") == 2
         assert "------ TRANSFORMED EVENTS: 2/2 ------" in captured.out
@@ -127,14 +130,16 @@ class TestRunLogprep:
                 "event_id": 1234,
                 "provider_name": "Test456",
                 "event_data": {"param1": "username"},
-            }
+            },
+            "message": "some message",
+            "field1": "field for the selective extractor",
         }
         input_json_file = os.path.join(tmp_path, "test_input.json")
         with open(input_json_file, "w", encoding="utf8") as input_file:
             json.dump(test_json, input_file)
 
         dry_runner = DryRunner(
-            dry_run=input_json_file,
+            input_file_path=input_json_file,
             config_path=self.config_path,
             full_output=True,
             use_json=True,
@@ -143,10 +148,10 @@ class TestRunLogprep:
         dry_runner.run()
 
         captured = capsys.readouterr()
+        assert captured.err == ""
         assert "------ PROCESSED EVENT ------" in captured.out
         assert "------ TRANSFORMED EVENTS: 1/1 ------" in captured.out
-        assert "------ ALL PSEUDONYMS ------" in captured.out
-        assert "------ ALL PRE-DETECTIONS ------" in captured.out
+        assert "------ CUSTOM OUTPUTS ------" in captured.out
 
     def test_dry_run_prints_predetection(self, tmp_path, capsys):
         test_json = {
@@ -160,7 +165,7 @@ class TestRunLogprep:
             json.dump(test_json, input_file)
 
         dry_runner = DryRunner(
-            dry_run=input_json_file,
+            input_file_path=input_json_file,
             config_path=self.config_path,
             full_output=True,
             use_json=True,
@@ -169,31 +174,7 @@ class TestRunLogprep:
         dry_runner.run()
 
         captured = capsys.readouterr()
+        assert captured.err == ""
         assert "------ PROCESSED EVENT ------" in captured.out
         assert "------ TRANSFORMED EVENTS: 1/1 ------" in captured.out
-        assert "------ ALL PSEUDONYMS ------" in captured.out
-        assert "------ ALL PRE-DETECTIONS ------" in captured.out
-
-    @mock.patch("logprep.processor.labeler.processor.Labeler.process", side_effect=BaseException)
-    def test_dry_run_prints_errors(self, _, tmp_path, capsys):
-        test_json = {
-            "winlog": {
-                "event_id": 123,
-                "event_data": {"ServiceName": "VERY BAD"},
-            }
-        }
-        input_json_file = os.path.join(tmp_path, "test_input.json")
-        with open(input_json_file, "w", encoding="utf8") as input_file:
-            json.dump(test_json, input_file)
-
-        dry_runner = DryRunner(
-            dry_run=input_json_file,
-            config_path=self.config_path,
-            full_output=True,
-            use_json=True,
-            logger=logging.getLogger("test-logger"),
-        )
-        dry_runner.run()
-
-        captured = capsys.readouterr()
-        assert "------ ERROR ------" in captured.out
+        assert "------ CUSTOM OUTPUTS ------" in captured.out
